#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class tangential_source(Boolean):
    """
    Include or not NRBC tangential source (default value #t).
    """

    fluent_name = "tangential-source?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .axis_from import axis_from as axis_from_cls
from .axis_to import axis_to as axis_to_cls
class second_axis(Group):
    """
    'second_axis' child.
    """

    fluent_name = "second-axis"

    child_names = \
        ['axis_from', 'axis_to']

    axis_from: axis_from_cls = axis_from_cls
    """
    axis_from child of second_axis.
    """
    axis_to: axis_to_cls = axis_to_cls
    """
    axis_to child of second_axis.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .solar_frequency_data import solar_frequency_data as solar_frequency_data_cls
from .solar_filename import solar_filename as solar_filename_cls
class autoread_solar_data(Group):
    """
    Set autoread solar data parameters.
    """

    fluent_name = "autoread-solar-data"

    child_names = \
        ['solar_frequency_data', 'solar_filename']

    solar_frequency_data: solar_frequency_data_cls = solar_frequency_data_cls
    """
    solar_frequency_data child of autoread_solar_data.
    """
    solar_filename: solar_filename_cls = solar_filename_cls
    """
    solar_filename child of autoread_solar_data.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .type_1 import type as type_cls
from .name_1 import name as name_cls
class copy_by_name(Command):
    """
    Copy a material from the database (pick by name).
    
    Parameters
    ----------
        type : str
            'type' child.
        name : str
            'name' child.
    
    """

    fluent_name = "copy-by-name"

    argument_names = \
        ['type', 'name']

    type: type_cls = type_cls
    """
    type argument of copy_by_name.
    """
    name: name_cls = name_cls
    """
    name argument of copy_by_name.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .viewfactor_settings import viewfactor_settings as viewfactor_settings_cls
from .clustering_settings import clustering_settings as clustering_settings_cls
from .radiosity_solver_control import radiosity_solver_control as radiosity_solver_control_cls
from .compute_write_vf import compute_write_vf as compute_write_vf_cls
from .compute_vf_accelerated import compute_vf_accelerated as compute_vf_accelerated_cls
from .compute_clusters_and_vf_accelerated import compute_clusters_and_vf_accelerated as compute_clusters_and_vf_accelerated_cls
from .compute_vf_only import compute_vf_only as compute_vf_only_cls
from .read_vf_file import read_vf_file as read_vf_file_cls
class s2s(Group):
    """
    's2s' child.
    """

    fluent_name = "s2s"

    child_names = \
        ['viewfactor_settings', 'clustering_settings',
         'radiosity_solver_control']

    viewfactor_settings: viewfactor_settings_cls = viewfactor_settings_cls
    """
    viewfactor_settings child of s2s.
    """
    clustering_settings: clustering_settings_cls = clustering_settings_cls
    """
    clustering_settings child of s2s.
    """
    radiosity_solver_control: radiosity_solver_control_cls = radiosity_solver_control_cls
    """
    radiosity_solver_control child of s2s.
    """
    command_names = \
        ['compute_write_vf', 'compute_vf_accelerated',
         'compute_clusters_and_vf_accelerated', 'compute_vf_only',
         'read_vf_file']

    compute_write_vf: compute_write_vf_cls = compute_write_vf_cls
    """
    compute_write_vf command of s2s.
    """
    compute_vf_accelerated: compute_vf_accelerated_cls = compute_vf_accelerated_cls
    """
    compute_vf_accelerated command of s2s.
    """
    compute_clusters_and_vf_accelerated: compute_clusters_and_vf_accelerated_cls = compute_clusters_and_vf_accelerated_cls
    """
    compute_clusters_and_vf_accelerated command of s2s.
    """
    compute_vf_only: compute_vf_only_cls = compute_vf_only_cls
    """
    compute_vf_only command of s2s.
    """
    read_vf_file: read_vf_file_cls = read_vf_file_cls
    """
    read_vf_file command of s2s.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .zone_names import zone_names as zone_names_cls
from .zone_name import zone_name as zone_name_cls
class fuse_face_zones(Command):
    """
    Attempt to fuse zones by removing duplicate faces and nodes.
    
    Parameters
    ----------
        zone_names : typing.List[str]
            Merge duplicate faces and nodes of zones in list.
        zone_name : str
            'zone_name' child.
    
    """

    fluent_name = "fuse-face-zones"

    argument_names = \
        ['zone_names', 'zone_name']

    zone_names: zone_names_cls = zone_names_cls
    """
    zone_names argument of fuse_face_zones.
    """
    zone_name: zone_name_cls = zone_name_cls
    """
    zone_name argument of fuse_face_zones.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .file_name_1 import file_name as file_name_cls
from .cell_func_domain_export import cell_func_domain_export as cell_func_domain_export_cls
class fieldview_data(Command):
    """
    Write Fieldview case and data files.
    
    Parameters
    ----------
        file_name : str
            'file_name' child.
        cell_func_domain_export : typing.List[str]
            'cell_func_domain_export' child.
    
    """

    fluent_name = "fieldview-data"

    argument_names = \
        ['file_name', 'cell_func_domain_export']

    file_name: file_name_cls = file_name_cls
    """
    file_name argument of fieldview_data.
    """
    cell_func_domain_export: cell_func_domain_export_cls = cell_func_domain_export_cls
    """
    cell_func_domain_export argument of fieldview_data.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_7 import option as option_cls
from .value_3 import value as value_cls
from .gray_band_coefficients import gray_band_coefficients as gray_band_coefficients_cls
class refractive_index(Group):
    """
    'refractive_index' child.
    """

    fluent_name = "refractive-index"

    child_names = \
        ['option', 'value', 'gray_band_coefficients']

    option: option_cls = option_cls
    """
    option child of refractive_index.
    """
    value: value_cls = value_cls
    """
    value child of refractive_index.
    """
    gray_band_coefficients: gray_band_coefficients_cls = gray_band_coefficients_cls
    """
    gray_band_coefficients child of refractive_index.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .random_eddy_lifetime import random_eddy_lifetime as random_eddy_lifetime_cls
from .number_of_tries import number_of_tries as number_of_tries_cls
from .time_scale_constant_1 import time_scale_constant as time_scale_constant_cls
from .length_scale_constant import length_scale_constant as length_scale_constant_cls
class turbulent_dispersion(Group):
    """
    'turbulent_dispersion' child.
    """

    fluent_name = "turbulent-dispersion"

    child_names = \
        ['option', 'random_eddy_lifetime', 'number_of_tries',
         'time_scale_constant', 'length_scale_constant']

    option: option_cls = option_cls
    """
    option child of turbulent_dispersion.
    """
    random_eddy_lifetime: random_eddy_lifetime_cls = random_eddy_lifetime_cls
    """
    random_eddy_lifetime child of turbulent_dispersion.
    """
    number_of_tries: number_of_tries_cls = number_of_tries_cls
    """
    number_of_tries child of turbulent_dispersion.
    """
    time_scale_constant: time_scale_constant_cls = time_scale_constant_cls
    """
    time_scale_constant child of turbulent_dispersion.
    """
    length_scale_constant: length_scale_constant_cls = length_scale_constant_cls
    """
    length_scale_constant child of turbulent_dispersion.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class fluxes:
    fluent_name = ...
    command_names = ...

    def mass_flow(self, domain_val: str, all_bndry_zones: bool, zone_list: List[str], write_to_file: bool, file_name: str, append_data: bool, overwrite: bool):
        """
        Print mass flow rate at inlets and outlets.
        
        Parameters
        ----------
            domain_val : str
                'domain_val' child.
            all_bndry_zones : bool
                Select all the boundary/interior zones.
            zone_list : typing.List[str]
                'zone_list' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
            overwrite : bool
                'overwrite' child.
        
        """

    def heat_transfer(self, domain_val: str, all_bndry_zones: bool, zone_list: List[str], write_to_file: bool, file_name: str, append_data: bool, overwrite: bool):
        """
        Print heat transfer rate at boundaries.
        
        Parameters
        ----------
            domain_val : str
                'domain_val' child.
            all_bndry_zones : bool
                Select all the boundary/interior zones.
            zone_list : typing.List[str]
                'zone_list' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
            overwrite : bool
                'overwrite' child.
        
        """

    def heat_transfer_sensible(self, domain_val: str, all_bndry_zones: bool, zone_list: List[str], write_to_file: bool, file_name: str, append_data: bool, overwrite: bool):
        """
        Print sensible heat transfer rate at boundaries.
        
        Parameters
        ----------
            domain_val : str
                'domain_val' child.
            all_bndry_zones : bool
                Select all the boundary/interior zones.
            zone_list : typing.List[str]
                'zone_list' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
            overwrite : bool
                'overwrite' child.
        
        """

    def rad_heat_trans(self, domain_val: str, all_bndry_zones: bool, zone_list: List[str], write_to_file: bool, file_name: str, append_data: bool, overwrite: bool):
        """
        Print radiation heat transfer rate at boundaries.
        
        Parameters
        ----------
            domain_val : str
                'domain_val' child.
            all_bndry_zones : bool
                Select all the boundary/interior zones.
            zone_list : typing.List[str]
                'zone_list' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
            overwrite : bool
                'overwrite' child.
        
        """

    def film_mass_flow(self, domain_val: str, all_bndry_zones: bool, zone_list: List[str], write_to_file: bool, file_name: str, append_data: bool, overwrite: bool):
        """
        Print film mass flow rate at boundaries.
        
        Parameters
        ----------
            domain_val : str
                'domain_val' child.
            all_bndry_zones : bool
                Select all the boundary/interior zones.
            zone_list : typing.List[str]
                'zone_list' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
            overwrite : bool
                'overwrite' child.
        
        """

    def film_heat_transfer(self, domain_val: str, all_bndry_zones: bool, zone_list: List[str], write_to_file: bool, file_name: str, append_data: bool, overwrite: bool):
        """
        Print film heat transfer rate at boundaries.
        
        Parameters
        ----------
            domain_val : str
                'domain_val' child.
            all_bndry_zones : bool
                Select all the boundary/interior zones.
            zone_list : typing.List[str]
                'zone_list' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
            overwrite : bool
                'overwrite' child.
        
        """

    def pressure_work(self, domain_val: str, all_bndry_zones: bool, zone_list: List[str], write_to_file: bool, file_name: str, append_data: bool, overwrite: bool):
        """
        Print pressure work rate at moving boundaries.
        
        Parameters
        ----------
            domain_val : str
                'domain_val' child.
            all_bndry_zones : bool
                Select all the boundary/interior zones.
            zone_list : typing.List[str]
                'zone_list' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
            overwrite : bool
                'overwrite' child.
        
        """

    def viscous_work(self, domain_val: str, all_bndry_zones: bool, zone_list: List[str], write_to_file: bool, file_name: str, append_data: bool, overwrite: bool):
        """
        Print viscous work rate at boundaries.
        
        Parameters
        ----------
            domain_val : str
                'domain_val' child.
            all_bndry_zones : bool
                Select all the boundary/interior zones.
            zone_list : typing.List[str]
                'zone_list' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
            overwrite : bool
                'overwrite' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .use import use as use_cls
from .use_user_define_value import use_user_define_value as use_user_define_value_cls
from .value_1 import value as value_cls
class solid_thread_weight(Group):
    """
    Use solid thread weights.
    """

    fluent_name = "solid-thread-weight"

    child_names = \
        ['use', 'use_user_define_value', 'value']

    use: use_cls = use_cls
    """
    use child of solid_thread_weight.
    """
    use_user_define_value: use_user_define_value_cls = use_user_define_value_cls
    """
    use_user_define_value child of solid_thread_weight.
    """
    value: value_cls = value_cls
    """
    value child of solid_thread_weight.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class relaxation_bounding_method(String, _HasAllowedValuesMixin):
    """
    'relaxation_bounding_method' child.
    """

    fluent_name = "relaxation-bounding-method"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
from .report_type import report_type as report_type_cls
from .user_specified_origin_and_axis import user_specified_origin_and_axis as user_specified_origin_and_axis_cls
from .origin import origin as origin_cls
from .axis_1 import axis as axis_cls
from .mass_criterion import mass_criterion as mass_criterion_cls
from .physics_1 import physics as physics_cls
from .boundary_zones_names import boundary_zones_names as boundary_zones_names_cls
from .boundary_zones import boundary_zones as boundary_zones_cls
from .retain_instantaneous_values import retain_instantaneous_values as retain_instantaneous_values_cls
from .inj_mass_rate_last_tstp import inj_mass_rate_last_tstp as inj_mass_rate_last_tstp_cls
from .inj_mass_rate_last_flow import inj_mass_rate_last_flow as inj_mass_rate_last_flow_cls
from .inj_mass_rate_prev_mass import inj_mass_rate_prev_mass as inj_mass_rate_prev_mass_cls
from .inj_mass_rate_prev_time import inj_mass_rate_prev_time as inj_mass_rate_prev_time_cls
from .show_unsteady_rate import show_unsteady_rate as show_unsteady_rate_cls
from .old_props import old_props as old_props_cls
from .average_over import average_over as average_over_cls
from .per_injection import per_injection as per_injection_cls
from .injection_list import injection_list as injection_list_cls
class injection_child(Group):
    """
    'child_object_type' of injection.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'report_type', 'user_specified_origin_and_axis', 'origin',
         'axis', 'mass_criterion', 'physics', 'boundary_zones_names',
         'boundary_zones', 'retain_instantaneous_values',
         'inj_mass_rate_last_tstp', 'inj_mass_rate_last_flow',
         'inj_mass_rate_prev_mass', 'inj_mass_rate_prev_time',
         'show_unsteady_rate', 'old_props', 'average_over', 'per_injection',
         'injection_list']

    name: name_cls = name_cls
    """
    name child of injection_child.
    """
    report_type: report_type_cls = report_type_cls
    """
    report_type child of injection_child.
    """
    user_specified_origin_and_axis: user_specified_origin_and_axis_cls = user_specified_origin_and_axis_cls
    """
    user_specified_origin_and_axis child of injection_child.
    """
    origin: origin_cls = origin_cls
    """
    origin child of injection_child.
    """
    axis: axis_cls = axis_cls
    """
    axis child of injection_child.
    """
    mass_criterion: mass_criterion_cls = mass_criterion_cls
    """
    mass_criterion child of injection_child.
    """
    physics: physics_cls = physics_cls
    """
    physics child of injection_child.
    """
    boundary_zones_names: boundary_zones_names_cls = boundary_zones_names_cls
    """
    boundary_zones_names child of injection_child.
    """
    boundary_zones: boundary_zones_cls = boundary_zones_cls
    """
    boundary_zones child of injection_child.
    """
    retain_instantaneous_values: retain_instantaneous_values_cls = retain_instantaneous_values_cls
    """
    retain_instantaneous_values child of injection_child.
    """
    inj_mass_rate_last_tstp: inj_mass_rate_last_tstp_cls = inj_mass_rate_last_tstp_cls
    """
    inj_mass_rate_last_tstp child of injection_child.
    """
    inj_mass_rate_last_flow: inj_mass_rate_last_flow_cls = inj_mass_rate_last_flow_cls
    """
    inj_mass_rate_last_flow child of injection_child.
    """
    inj_mass_rate_prev_mass: inj_mass_rate_prev_mass_cls = inj_mass_rate_prev_mass_cls
    """
    inj_mass_rate_prev_mass child of injection_child.
    """
    inj_mass_rate_prev_time: inj_mass_rate_prev_time_cls = inj_mass_rate_prev_time_cls
    """
    inj_mass_rate_prev_time child of injection_child.
    """
    show_unsteady_rate: show_unsteady_rate_cls = show_unsteady_rate_cls
    """
    show_unsteady_rate child of injection_child.
    """
    old_props: old_props_cls = old_props_cls
    """
    old_props child of injection_child.
    """
    average_over: average_over_cls = average_over_cls
    """
    average_over child of injection_child.
    """
    per_injection: per_injection_cls = per_injection_cls
    """
    per_injection child of injection_child.
    """
    injection_list: injection_list_cls = injection_list_cls
    """
    injection_list child of injection_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class xy_plot_child:
    fluent_name = ...
    child_names = ...
    name = ...
    uid = ...
    options = ...
    plot_direction = ...
    x_axis_function = ...
    y_axis_function = ...
    surfaces_list = ...
    physics = ...
    geometry = ...
    surfaces = ...
    axes = ...
    curves = ...
    command_names = ...

    def display(self, ):
        """
        'display' command.
        """

    def write_to_file(self, filename: str):
        """
        Write data to file.
        
        Parameters
        ----------
            filename : str
                Enter file name.
        
        """

    def read_from_file(self, filename: str):
        """
        Read data from file.
        
        Parameters
        ----------
            filename : str
                Enter file name.
        
        """

    def free_file_data(self, file_data_list: List[str]):
        """
        Free file-data.
        
        Parameters
        ----------
            file_data_list : typing.List[str]
                File-data to delete.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .active import active as active_cls
from .value_1 import value as value_cls
from .transparency import transparency as transparency_cls
from .color_2 import color as color_cls
class settings_child(Group):
    """
    'child_object_type' of settings.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['active', 'value', 'transparency', 'color']

    active: active_cls = active_cls
    """
    active child of settings_child.
    """
    value: value_cls = value_cls
    """
    value child of settings_child.
    """
    transparency: transparency_cls = transparency_cls
    """
    transparency child of settings_child.
    """
    color: color_cls = color_cls
    """
    color child of settings_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class use_vapor_species_heat_capacity(Boolean):
    """
    'use_vapor_species_heat_capacity' child.
    """

    fluent_name = "use-vapor-species-heat-capacity?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .number_of_represented_species import number_of_represented_species as number_of_represented_species_cls
from .full_mechanism_material_name import full_mechanism_material_name as full_mechanism_material_name_cls
from .fuel_oxidizer_species import fuel_oxidizer_species as fuel_oxidizer_species_cls
class dimension_reduction_mixture_options(Group):
    """
    'dimension_reduction_mixture_options' child.
    """

    fluent_name = "dimension-reduction-mixture-options"

    child_names = \
        ['number_of_represented_species', 'full_mechanism_material_name',
         'fuel_oxidizer_species']

    number_of_represented_species: number_of_represented_species_cls = number_of_represented_species_cls
    """
    number_of_represented_species child of dimension_reduction_mixture_options.
    """
    full_mechanism_material_name: full_mechanism_material_name_cls = full_mechanism_material_name_cls
    """
    full_mechanism_material_name child of dimension_reduction_mixture_options.
    """
    fuel_oxidizer_species: fuel_oxidizer_species_cls = fuel_oxidizer_species_cls
    """
    fuel_oxidizer_species child of dimension_reduction_mixture_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .filepath import filepath as filepath_cls
class export_design_table(Command):
    """
    Export Design Point Table.
    
    Parameters
    ----------
        filepath : str
            'filepath' child.
    
    """

    fluent_name = "export-design-table"

    argument_names = \
        ['filepath']

    filepath: filepath_cls = filepath_cls
    """
    filepath argument of export_design_table.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .f_length import f_length as f_length_cls
from .re_theta_c import re_theta_c as re_theta_c_cls
from .re_theta_t import re_theta_t as re_theta_t_cls
class user_defined_transition(Group):
    """
    Set user-defined transition correlations.
    """

    fluent_name = "user-defined-transition"

    child_names = \
        ['f_length', 're_theta_c', 're_theta_t']

    f_length: f_length_cls = f_length_cls
    """
    f_length child of user_defined_transition.
    """
    re_theta_c: re_theta_c_cls = re_theta_c_cls
    """
    re_theta_c child of user_defined_transition.
    """
    re_theta_t: re_theta_t_cls = re_theta_t_cls
    """
    re_theta_t child of user_defined_transition.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class print_thread_clusters(Command):
    """
    Prints the following for all boundary threads: thread-id, number of faces, faces per surface cluster, and the number of surface clusters.
    """

    fluent_name = "print-thread-clusters"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class high_order_rc_hybrid_treatment(Boolean):
    """
    Enable/disable use of hybrid treatment for high order Rhie-Chow flux.
    """

    fluent_name = "high-order-rc-hybrid-treatment?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .thermal_expansion_0 import thermal_expansion_0 as thermal_expansion_0_cls
from .thermal_expansion_1 import thermal_expansion_1 as thermal_expansion_1_cls
from .thermal_expansion_2 import thermal_expansion_2 as thermal_expansion_2_cls
class orthotropic_structure_te(Group):
    """
    'orthotropic_structure_te' child.
    """

    fluent_name = "orthotropic-structure-te"

    child_names = \
        ['thermal_expansion_0', 'thermal_expansion_1', 'thermal_expansion_2']

    thermal_expansion_0: thermal_expansion_0_cls = thermal_expansion_0_cls
    """
    thermal_expansion_0 child of orthotropic_structure_te.
    """
    thermal_expansion_1: thermal_expansion_1_cls = thermal_expansion_1_cls
    """
    thermal_expansion_1 child of orthotropic_structure_te.
    """
    thermal_expansion_2: thermal_expansion_2_cls = thermal_expansion_2_cls
    """
    thermal_expansion_2 child of orthotropic_structure_te.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .list_properties_1 import list_properties as list_properties_cls
from .impedance_1_child import impedance_1_child

class impedance_1(ListObject[impedance_1_child]):
    """
    'impedance_1' child.
    """

    fluent_name = "impedance-1"

    command_names = \
        ['list_properties']

    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of impedance_1.
    """
    child_object_type: impedance_1_child = impedance_1_child
    """
    child_object_type of impedance_1.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_6 import option as option_cls
from .partitioning_method_for_dpm_domain import partitioning_method_for_dpm_domain as partitioning_method_for_dpm_domain_cls
class dpm_domain(Group):
    """
    'dpm_domain' child.
    """

    fluent_name = "dpm-domain"

    child_names = \
        ['option', 'partitioning_method_for_dpm_domain']

    option: option_cls = option_cls
    """
    option child of dpm_domain.
    """
    partitioning_method_for_dpm_domain: partitioning_method_for_dpm_domain_cls = partitioning_method_for_dpm_domain_cls
    """
    partitioning_method_for_dpm_domain child of dpm_domain.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class network:
    fluent_name = ...
    child_names = ...
    shell_script_path = ...
    command_names = ...

    def kill_all_nodes(self, invalidate_case: bool, delete_all_compute_nodes: bool):
        """
        Delete all compute nodes from virtual machine.
        
        Parameters
        ----------
            invalidate_case : bool
                'invalidate_case' child.
            delete_all_compute_nodes : bool
                'delete_all_compute_nodes' child.
        
        """

    def kill_node(self, compute_node: int, invalidate_case: bool):
        """
        'kill_node' command.
        
        Parameters
        ----------
            compute_node : int
                'compute_node' child.
            invalidate_case : bool
                'invalidate_case' child.
        
        """

    def spawn_node(self, hostname: str, username: str):
        """
        Spawn a compute node process on a specified machine.
        
        Parameters
        ----------
            hostname : str
                'hostname' child.
            username : str
                'username' child.
        
        """

    def load_hosts(self, host_file: str):
        """
        Read a hosts file.
        
        Parameters
        ----------
            host_file : str
                'host_file' child.
        
        """

    def save_hosts(self, host_file: str):
        """
        Write a hosts file.
        
        Parameters
        ----------
            host_file : str
                'host_file' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .iter_per_coupling_count import iter_per_coupling_count as iter_per_coupling_count_cls
from .single_session_coupling import single_session_coupling as single_session_coupling_cls
from .two_session_coupling import two_session_coupling as two_session_coupling_cls
class coupling(Group):
    """
    'coupling' child.
    """

    fluent_name = "coupling"

    child_names = \
        ['iter_per_coupling_count', 'single_session_coupling',
         'two_session_coupling']

    iter_per_coupling_count: iter_per_coupling_count_cls = iter_per_coupling_count_cls
    """
    iter_per_coupling_count child of coupling.
    """
    single_session_coupling: single_session_coupling_cls = single_session_coupling_cls
    """
    single_session_coupling child of coupling.
    """
    two_session_coupling: two_session_coupling_cls = two_session_coupling_cls
    """
    two_session_coupling child of coupling.
    """



from concurrent import futures
import os
from pathlib import Path
import tempfile
import time

import grpc
from grpc_health.v1 import health_pb2, health_pb2_grpc
import pytest
from util.meshing_workflow import new_mesh_session  # noqa: F401
from util.solver_workflow import make_new_session, new_solver_session  # noqa: F401

from ansys.api.fluent.v0 import (
    scheme_eval_pb2,
    scheme_eval_pb2_grpc,
    settings_pb2,
    settings_pb2_grpc,
)
from ansys.api.fluent.v0.scheme_pointer_pb2 import SchemePointer
import ansys.fluent.core as pyfluent
from ansys.fluent.core import connect_to_fluent, examples, session
from ansys.fluent.core.fluent_connection import FluentConnection, PortNotProvided
from ansys.fluent.core.launcher.launcher_utils import LaunchFluentError
from ansys.fluent.core.session import BaseSession
from ansys.fluent.core.utils.execution import timeout_loop
from ansys.fluent.core.utils.networking import get_free_port


class MockSettingsServicer(settings_pb2_grpc.SettingsServicer):
    def GetStaticInfo(
        self, request: settings_pb2.GetStaticInfoRequest, context: grpc.ServicerContext
    ) -> settings_pb2.GetStaticInfoResponse:
        response = settings_pb2.GetStaticInfoResponse()
        response.info.type = "Dummy"
        return response

    def GetVar(
        self,
        request: settings_pb2.GetVarRequest,
        context: grpc.ServicerContext,
    ) -> settings_pb2.GetVarResponse:
        response = settings_pb2.GetVarResponse()
        response.value.value_map.SetInParent()
        return response


class MockHealthServicer(health_pb2_grpc.HealthServicer):
    def Check(self, request, context: grpc.ServicerContext):  # noqa N802
        metadata = dict(context.invocation_metadata())
        password = metadata.get("password", None)
        if password != "12345":
            context.set_code(grpc.StatusCode.UNAUTHENTICATED)
            return health_pb2.HealthCheckResponse()
        return health_pb2.HealthCheckResponse(
            status=health_pb2.HealthCheckResponse.ServingStatus.SERVING
        )

    def Watch(self, request, context: grpc.ServicerContext):  # noqa N802
        metadata = dict(context.invocation_metadata())
        password = metadata.get("password", None)
        if password != "12345":
            context.set_code(grpc.StatusCode.UNAUTHENTICATED)
            yield health_pb2.HealthCheckResponse()

        c = 0
        while c < 2:
            time.sleep(1)
            c += 1
            yield health_pb2.HealthCheckResponse(
                status=health_pb2.HealthCheckResponse.ServingStatus.NOT_SERVING
            )

        time.sleep(1)
        yield health_pb2.HealthCheckResponse(
            status=health_pb2.HealthCheckResponse.ServingStatus.SERVING
        )


class MockSchemeEvalServicer(scheme_eval_pb2_grpc.SchemeEvalServicer):
    def StringEval(self, request, context):
        if request.input == "(cx-version)":
            return scheme_eval_pb2.StringEvalResponse(output="(23 1 0)")

    def SchemeEval(
        self,
        request,
        context: grpc.ServicerContext,
    ) -> scheme_eval_pb2.SchemeEvalResponse:
        metadata = dict(context.invocation_metadata())
        password = metadata.get("password", None)
        if password != "12345":
            context.set_code(grpc.StatusCode.UNAUTHENTICATED)
        return scheme_eval_pb2.SchemeEvalResponse(output=SchemePointer(b=True))


def test_create_mock_session_by_passing_ip_port_password() -> None:
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=1))
    ip = "127.0.0.1"
    port = get_free_port()
    server.add_insecure_port(f"{ip}:{port}")
    health_pb2_grpc.add_HealthServicer_to_server(MockHealthServicer(), server)
    scheme_eval_pb2_grpc.add_SchemeEvalServicer_to_server(
        MockSchemeEvalServicer(), server
    )
    server.start()

    with pytest.raises(PortNotProvided) as msg:
        session = BaseSession(
            FluentConnection(ip=ip, password="12345", cleanup_on_exit=False)
        )

    session = BaseSession(
        FluentConnection(ip=ip, port=port, password="12345", cleanup_on_exit=False)
    )
    assert session.health_check_service.is_serving
    server.stop(None)
    session.exit()
    assert not session.health_check_service.is_serving


def test_create_mock_session_by_setting_ip_port_env_var(
    monkeypatch: pytest.MonkeyPatch,
) -> None:
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=1))
    ip = "127.0.0.1"
    port = get_free_port()
    server.add_insecure_port(f"{ip}:{port}")
    health_pb2_grpc.add_HealthServicer_to_server(MockHealthServicer(), server)
    scheme_eval_pb2_grpc.add_SchemeEvalServicer_to_server(
        MockSchemeEvalServicer(), server
    )
    server.start()
    monkeypatch.setenv("PYFLUENT_FLUENT_IP", ip)
    monkeypatch.setenv("PYFLUENT_FLUENT_PORT", str(port))
    session = BaseSession(FluentConnection(password="12345", cleanup_on_exit=False))
    assert session.health_check_service.is_serving
    server.stop(None)
    session.exit()
    assert not session.health_check_service.is_serving


def test_create_mock_session_by_passing_grpc_channel() -> None:
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=1))
    ip = "127.0.0.1"
    port = get_free_port()
    server.add_insecure_port(f"{ip}:{port}")
    health_pb2_grpc.add_HealthServicer_to_server(MockHealthServicer(), server)
    scheme_eval_pb2_grpc.add_SchemeEvalServicer_to_server(
        MockSchemeEvalServicer(), server
    )
    server.start()
    channel = grpc.insecure_channel(f"{ip}:{port}")
    session = BaseSession(
        FluentConnection(channel=channel, cleanup_on_exit=False, password="12345")
    )
    assert session.health_check_service.is_serving
    server.stop(None)
    session.exit()
    assert not session.health_check_service.is_serving


def test_create_mock_session_from_server_info_file(tmp_path: Path) -> None:
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=1))
    ip = "127.0.0.1"
    port = get_free_port()
    server.add_insecure_port(f"{ip}:{port}")
    health_pb2_grpc.add_HealthServicer_to_server(MockHealthServicer(), server)
    scheme_eval_pb2_grpc.add_SchemeEvalServicer_to_server(
        MockSchemeEvalServicer(), server
    )
    server.start()
    server_info_file = tmp_path / "server_info.txt"
    server_info_file.write_text(f"{ip}:{port}\n12345")
    session = BaseSession.create_from_server_info_file(
        server_info_file_name=str(server_info_file), cleanup_on_exit=False
    )
    assert session.health_check_service.is_serving
    server.stop(None)
    session.exit()
    assert not session.health_check_service.is_serving


def test_create_mock_session_from_server_info_file_with_wrong_password(
    tmp_path: Path,
) -> None:
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=1))
    ip = "127.0.0.1"
    port = get_free_port()
    server.add_insecure_port(f"{ip}:{port}")
    scheme_eval_pb2_grpc.add_SchemeEvalServicer_to_server(
        MockSchemeEvalServicer(), server
    )
    health_pb2_grpc.add_HealthServicer_to_server(MockHealthServicer(), server)
    server.start()
    server_info_file = tmp_path / "server_info.txt"
    server_info_file.write_text(f"{ip}:{port}\n1234")
    with pytest.raises(RuntimeError) as ex:
        session = BaseSession.create_from_server_info_file(
            server_info_file_name=str(server_info_file),
            cleanup_on_exit=False,
        )
        session.scheme_eval.scheme_eval("")
        server.stop(None)
        session.exit()
    assert ex.value.__context__.code() == grpc.StatusCode.UNAUTHENTICATED


def test_create_mock_session_from_launch_fluent_by_passing_ip_port_password() -> None:
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=1))
    ip = "127.0.0.1"
    port = get_free_port()
    server.add_insecure_port(f"{ip}:{port}")
    health_pb2_grpc.add_HealthServicer_to_server(MockHealthServicer(), server)
    scheme_eval_pb2_grpc.add_SchemeEvalServicer_to_server(
        MockSchemeEvalServicer(), server
    )
    settings_pb2_grpc.add_SettingsServicer_to_server(MockSettingsServicer(), server)
    server.start()
    session = connect_to_fluent(
        ip=ip,
        port=port,
        cleanup_on_exit=False,
        password="12345",
    )
    # check a few dir elements
    session_dir = dir(session)
    for attr in ("field_data", "field_info"):
        assert attr in session_dir
    assert session.health_check_service.is_serving
    server.stop(None)
    session.exit()
    assert not session.health_check_service.is_serving


def test_create_mock_session_from_launch_fluent_by_setting_ip_port_env_var(
    monkeypatch: pytest.MonkeyPatch,
) -> None:
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=1))
    ip = "127.0.0.1"
    port = get_free_port()
    server.add_insecure_port(f"{ip}:{port}")
    health_pb2_grpc.add_HealthServicer_to_server(MockHealthServicer(), server)
    scheme_eval_pb2_grpc.add_SchemeEvalServicer_to_server(
        MockSchemeEvalServicer(), server
    )
    settings_pb2_grpc.add_SettingsServicer_to_server(MockSettingsServicer(), server)
    server.start()
    monkeypatch.setenv("PYFLUENT_FLUENT_IP", ip)
    monkeypatch.setenv("PYFLUENT_FLUENT_PORT", str(port))
    session = connect_to_fluent(
        cleanup_on_exit=False, ip=ip, port=port, password="12345"
    )
    # check a few dir elements
    session_dir = dir(session)
    for attr in ("field_data", "field_info"):
        assert attr in session_dir
    assert session.health_check_service.is_serving
    server.stop(None)
    session.exit()
    assert not session.health_check_service.is_serving


@pytest.mark.parametrize("file_format", ["jou", "py"])
@pytest.mark.fluent_version(">=23.2")
def test_journal_creation(file_format, new_mesh_session):
    fd, file_name = tempfile.mkstemp(
        suffix=f"-{os.getpid()}.{file_format}",
        prefix="pyfluent-",
        dir=str(pyfluent.EXAMPLES_PATH),
    )
    os.close(fd)

    file_name = Path(file_name)

    file_name.touch()
    prev_stat = file_name.stat()
    prev_mtime = prev_stat.st_mtime
    prev_size = prev_stat.st_size
    print(f"prev_stat: {prev_stat}")

    session = new_mesh_session
    if session.connection_properties.inside_container:
        session.journal.start(file_name.name)
    else:
        session.journal.start(file_name)
    session = session.switch_to_solver()
    session.journal.stop()
    new_stat = file_name.stat()
    print(f"new_stat: {new_stat}")
    assert new_stat.st_mtime > prev_mtime or new_stat.st_size > prev_size


@pytest.mark.fluent_version(">=23.2")
def test_start_transcript_file_write(new_mesh_session):
    fd, file_name = tempfile.mkstemp(
        suffix=f"-{os.getpid()}.trn",
        prefix="pyfluent-",
        dir=str(pyfluent.EXAMPLES_PATH),
    )
    os.close(fd)

    file_name = Path(file_name)

    file_name.touch()
    prev_stat = file_name.stat()
    prev_mtime = prev_stat.st_mtime
    prev_size = prev_stat.st_size

    session = new_mesh_session
    session.transcript.start(file_name)
    session = session.switch_to_solver()
    session.transcript.stop()

    new_stat = file_name.stat()
    assert new_stat.st_mtime > prev_mtime or new_stat.st_size > prev_size


@pytest.mark.fluent_version(">=23.1")
def test_expected_interfaces_in_solver_session(new_solver_session):
    assert all(
        intf in dir(new_solver_session) for intf in ("preferences", "tui", "workflow")
    )


@pytest.mark.fluent_version(">=24.1")
def test_solverworkflow_not_in_solver_session(new_solver_session):
    assert "solverworkflow" not in dir(new_solver_session)


@pytest.mark.standalone
@pytest.mark.fluent_version(">=23.2")
def test_read_case_using_lightweight_mode():
    import_file_name = examples.download_file(
        "mixing_elbow.cas.h5", "pyfluent/mixing_elbow"
    )
    solver = pyfluent.launch_fluent(
        case_file_name=import_file_name, lightweight_mode=True
    )
    solver.setup.models.energy.enabled = False
    old_fluent_connection_id = id(solver.fluent_connection)
    timeout_loop(
        id(solver.fluent_connection) != old_fluent_connection_id,
        timeout=60,
        idle_period=1,
    )
    timeout_loop(
        solver.setup.models.energy.enabled() == False,
        timeout=60,
        idle_period=1,
    )
    solver.exit()


def test_help_does_not_throw(new_solver_session):
    help(new_solver_session.file.read)


def test_build_from_fluent_connection(make_new_session):
    solver1 = make_new_session()
    solver2 = make_new_session()
    assert solver1.health_check_service.is_serving
    assert solver2.health_check_service.is_serving
    health_check_service1 = solver1.health_check_service
    cortex_pid2 = solver2.fluent_connection.connection_properties.cortex_pid
    solver1.build_from_fluent_connection(solver2.fluent_connection)
    assert solver1.health_check_service.is_serving
    assert solver2.health_check_service.is_serving
    assert not health_check_service1.is_serving
    assert solver1.fluent_connection.connection_properties.cortex_pid == cortex_pid2
    assert solver2.fluent_connection.connection_properties.cortex_pid == cortex_pid2


@pytest.mark.standalone
def test_recover_grpc_error_from_launch_error(monkeypatch: pytest.MonkeyPatch):
    orig_parse_server_info_file = session._parse_server_info_file

    def mock_parse_server_info_file(file_name):
        ip, port, password = orig_parse_server_info_file(file_name)
        return ip, port - 1, password  # provide wrong port

    monkeypatch.setattr(session, "_parse_server_info_file", mock_parse_server_info_file)
    with pytest.raises(LaunchFluentError) as ex:
        solver = pyfluent.launch_fluent()
    # grpc.RpcError -> RuntimeError -> LaunchFluentError
    assert ex.value.__context__.__context__.code() == grpc.StatusCode.UNAVAILABLE


def test_recover_grpc_error_from_connection_error():
    with pytest.raises(RuntimeError) as ex:
        pyfluent.connect_to_fluent(ip="127.0.0.1", port=50000, password="abcdefg")
    assert ex.value.__context__.code() == grpc.StatusCode.UNAVAILABLE


def test_solver_methods(new_solver_session):
    solver = new_solver_session

    if int(solver.version) == 222:
        api_keys = {
            "file",
            "setup",
            "solution",
            "results",
            "parametric_studies",
            "current_parametric_study",
        }
        assert api_keys.issubset(set(dir(solver)))
    if int(solver.version) == 232:
        api_keys = {
            "file",
            "mesh",
            "server",
            "setup",
            "solution",
            "results",
            "parametric_studies",
            "current_parametric_study",
            "parallel",
            "report",
        }
        assert api_keys.issubset(set(dir(solver)))
    if int(solver.version) >= 241:
        api_keys = {
            "file",
            "mesh",
            "server",
            "setup",
            "solution",
            "results",
            "parametric_studies",
            "current_parametric_study",
            "parallel",
        }
        assert api_keys.issubset(set(dir(solver)))



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .material_1 import material as material_cls
from .cylindrical_fixed_var import cylindrical_fixed_var as cylindrical_fixed_var_cls
from .participates_in_radiation import participates_in_radiation as participates_in_radiation_cls
from .contact_property import contact_property as contact_property_cls
from .active_wetsteam_zone import active_wetsteam_zone as active_wetsteam_zone_cls
from .vapor_phase_realgas import vapor_phase_realgas as vapor_phase_realgas_cls
from .laminar import laminar as laminar_cls
from .glass import glass as glass_cls
from .reference_frame_1 import reference_frame as reference_frame_cls
from .mesh_motion_1 import mesh_motion as mesh_motion_cls
from .porous_zone import porous_zone as porous_zone_cls
from .fan_zone_1 import fan_zone as fan_zone_cls
from .embedded_les import embedded_les as embedded_les_cls
from .reaction import reaction as reaction_cls
from .source_terms_3 import source_terms as source_terms_cls
from .fixed_values import fixed_values as fixed_values_cls
from .multiphase_1 import multiphase as multiphase_cls
from .disabled import disabled as disabled_cls
class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['material', 'cylindrical_fixed_var', 'participates_in_radiation',
         'contact_property', 'active_wetsteam_zone', 'vapor_phase_realgas',
         'laminar', 'glass', 'reference_frame', 'mesh_motion', 'porous_zone',
         'fan_zone', 'embedded_les', 'reaction', 'source_terms',
         'fixed_values', 'multiphase', 'disabled']

    material: material_cls = material_cls
    """
    material child of phase_child.
    """
    cylindrical_fixed_var: cylindrical_fixed_var_cls = cylindrical_fixed_var_cls
    """
    cylindrical_fixed_var child of phase_child.
    """
    participates_in_radiation: participates_in_radiation_cls = participates_in_radiation_cls
    """
    participates_in_radiation child of phase_child.
    """
    contact_property: contact_property_cls = contact_property_cls
    """
    contact_property child of phase_child.
    """
    active_wetsteam_zone: active_wetsteam_zone_cls = active_wetsteam_zone_cls
    """
    active_wetsteam_zone child of phase_child.
    """
    vapor_phase_realgas: vapor_phase_realgas_cls = vapor_phase_realgas_cls
    """
    vapor_phase_realgas child of phase_child.
    """
    laminar: laminar_cls = laminar_cls
    """
    laminar child of phase_child.
    """
    glass: glass_cls = glass_cls
    """
    glass child of phase_child.
    """
    reference_frame: reference_frame_cls = reference_frame_cls
    """
    reference_frame child of phase_child.
    """
    mesh_motion: mesh_motion_cls = mesh_motion_cls
    """
    mesh_motion child of phase_child.
    """
    porous_zone: porous_zone_cls = porous_zone_cls
    """
    porous_zone child of phase_child.
    """
    fan_zone: fan_zone_cls = fan_zone_cls
    """
    fan_zone child of phase_child.
    """
    embedded_les: embedded_les_cls = embedded_les_cls
    """
    embedded_les child of phase_child.
    """
    reaction: reaction_cls = reaction_cls
    """
    reaction child of phase_child.
    """
    source_terms: source_terms_cls = source_terms_cls
    """
    source_terms child of phase_child.
    """
    fixed_values: fixed_values_cls = fixed_values_cls
    """
    fixed_values child of phase_child.
    """
    multiphase: multiphase_cls = multiphase_cls
    """
    multiphase child of phase_child.
    """
    disabled: disabled_cls = disabled_cls
    """
    disabled child of phase_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .t0_1 import t0 as t0_cls
class thermal(Group):
    """
    Help not available.
    """

    fluent_name = "thermal"

    child_names = \
        ['t0']

    t0: t0_cls = t0_cls
    """
    t0 child of thermal.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .sample_file import sample_file as sample_file_cls
class read_sample_file(Command):
    """
    Read a sample file and add it to the sample list.
    
    Parameters
    ----------
        sample_file : str
            Enter the name of a sample file to be loaded.
    
    """

    fluent_name = "read-sample-file"

    argument_names = \
        ['sample_file']

    sample_file: sample_file_cls = sample_file_cls
    """
    sample_file argument of read_sample_file.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class vof_smooth_options:
    fluent_name = ...
    child_names = ...
    patch_reconstructed_interface = ...
    use_volumetric_smoothing = ...
    smoothing_relaxation_factor = ...
    command_names = ...

    def execute_smoothing(self, ):
        """
        Execute volumetric smoothing for volume fraction.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .nfaces_as_weights import nfaces_as_weights as nfaces_as_weights_cls
from .user_defined_value import user_defined_value as user_defined_value_cls
from .value_1 import value as value_cls
class nfaces_as_weights(Group):
    """
    Use number of faces as weights.
    """

    fluent_name = "nfaces-as-weights"

    child_names = \
        ['nfaces_as_weights', 'user_defined_value', 'value']

    nfaces_as_weights: nfaces_as_weights_cls = nfaces_as_weights_cls
    """
    nfaces_as_weights child of nfaces_as_weights.
    """
    user_defined_value: user_defined_value_cls = user_defined_value_cls
    """
    user_defined_value child of nfaces_as_weights.
    """
    value: value_cls = value_cls
    """
    value child of nfaces_as_weights.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .modified_setting import modified_setting as modified_setting_cls
from .write_user_setting import write_user_setting as write_user_setting_cls
class modified_setting_options(Group):
    """
    'modified_setting_options' child.
    """

    fluent_name = "modified-setting-options"

    command_names = \
        ['modified_setting', 'write_user_setting']

    modified_setting: modified_setting_cls = modified_setting_cls
    """
    modified_setting command of modified_setting_options.
    """
    write_user_setting: write_user_setting_cls = write_user_setting_cls
    """
    write_user_setting command of modified_setting_options.
    """



"""Wrappers over Meshing queries gRPC service of Fluent."""

from typing import Any, List, Tuple

import grpc

from ansys.api.fluent.v0 import meshing_queries_pb2 as MeshingQueriesProtoModule
from ansys.api.fluent.v0 import meshing_queries_pb2_grpc as MeshingQueriesGrpcModule
from ansys.fluent.core.exceptions import DisallowedValuesError
from ansys.fluent.core.services.error_handler import catch_grpc_error
from ansys.fluent.core.services.interceptors import (
    BatchInterceptor,
    ErrorStateInterceptor,
    TracingInterceptor,
)

Path = List[Tuple[str, str]]


class MeshingQueriesService:
    """Meshing Queries Service."""

    def __init__(
        self, channel: grpc.Channel, metadata: List[Tuple[str, str]], fluent_error_state
    ):
        """__init__ method of MeshingQueriesService class."""
        intercept_channel = grpc.intercept_channel(
            channel,
            ErrorStateInterceptor(fluent_error_state),
            TracingInterceptor(),
            BatchInterceptor(),
        )
        self._stub = MeshingQueriesGrpcModule.MeshingQueriesStub(intercept_channel)
        self._metadata = metadata

    @catch_grpc_error
    def get_face_zone_at_location(
        self, request: MeshingQueriesProtoModule.GetFaceZoneAtLocationRequest
    ) -> MeshingQueriesProtoModule.GetFaceZoneAtLocationResponse:
        """get_face_zone_at_location RPC of MeshingQueriesService."""
        return self._stub.GetFaceZoneAtLocation(request, metadata=self._metadata)

    @catch_grpc_error
    def get_cell_zone_at_location(
        self, request: MeshingQueriesProtoModule.GetCellZoneAtLocationRequest
    ) -> MeshingQueriesProtoModule.GetCellZoneAtLocationResponse:
        """get_cell_zone_at_location RPC of MeshingQueriesService."""
        return self._stub.GetCellZoneAtLocation(request, metadata=self._metadata)

    @catch_grpc_error
    def get_zones_of_type(
        self, request: MeshingQueriesProtoModule.GetZonesOfTypeRequest
    ) -> MeshingQueriesProtoModule.GetZonesOfTypeResponse:
        """get_zones_of_type RPC of MeshingQueriesService."""
        return self._stub.GetZonesOfType(request, metadata=self._metadata)

    @catch_grpc_error
    def get_zones_of_group(
        self, request: MeshingQueriesProtoModule.GetZonesOfGroupRequest
    ) -> MeshingQueriesProtoModule.GetZonesOfGroupResponse:
        """get_zones_of_group RPC of MeshingQueriesService."""
        return self._stub.GetZonesOfGroup(request, metadata=self._metadata)

    @catch_grpc_error
    def get_face_zones_of_filter(
        self, request: MeshingQueriesProtoModule.GetFaceZonesOfFilterRequest
    ) -> MeshingQueriesProtoModule.GetFaceZonesOfFilterResponse:
        """get_face_zones_of_filter RPC of MeshingQueriesService."""
        return self._stub.GetFaceZonesOfFilter(request, metadata=self._metadata)

    @catch_grpc_error
    def get_cell_zones_of_filter(
        self, request: MeshingQueriesProtoModule.GetCellZonesOfFilterRequest
    ) -> MeshingQueriesProtoModule.GetCellZonesOfFilterResponse:
        """get_cell_zones_of_filter RPC of MeshingQueriesService."""
        return self._stub.GetCellZonesOfFilter(request, metadata=self._metadata)

    @catch_grpc_error
    def get_edge_zones_of_filter(
        self, request: MeshingQueriesProtoModule.GetEdgeZonesOfFilterRequest
    ) -> MeshingQueriesProtoModule.GetEdgeZonesOfFilterResponse:
        """get_edge_zones_of_filter RPC of MeshingQueriesService."""
        return self._stub.GetEdgeZonesOfFilter(request, metadata=self._metadata)

    @catch_grpc_error
    def get_node_zones_of_filter(
        self, request: MeshingQueriesProtoModule.GetNodeZonesOfFilterRequest
    ) -> MeshingQueriesProtoModule.GetNodeZonesOfFilterResponse:
        """get_node_zones_of_filter RPC of MeshingQueriesService."""
        return self._stub.GetNodeZonesOfFilter(request, metadata=self._metadata)

    @catch_grpc_error
    def get_objects_of_type(
        self, request: MeshingQueriesProtoModule.GetObjectsOfTypeRequest
    ) -> MeshingQueriesProtoModule.GetObjectsOfTypeResponse:
        """get_objects_of_type RPC of MeshingQueriesService."""
        return self._stub.GetObjectsOfType(request, metadata=self._metadata)

    @catch_grpc_error
    def get_face_zone_id_list_of_object(
        self, request: MeshingQueriesProtoModule.GetFaceZoneIdListOfObjectRequest
    ) -> MeshingQueriesProtoModule.GetFaceZoneIdListOfObjectResponse:
        """get_face_zone_id_list_of_object RPC of MeshingQueriesService."""
        return self._stub.GetFaceZoneIdListOfObject(request, metadata=self._metadata)

    @catch_grpc_error
    def get_edge_zone_id_list_of_object(
        self, request: MeshingQueriesProtoModule.GetEdgeZoneIdListOfObjectRequest
    ) -> MeshingQueriesProtoModule.GetEdgeZoneIdListOfObjectResponse:
        """get_edge_zone_id_list_of_object RPC of MeshingQueriesService."""
        return self._stub.GetEdgeZoneIdListOfObject(request, metadata=self._metadata)

    @catch_grpc_error
    def get_cell_zone_id_list_of_object(
        self, request: MeshingQueriesProtoModule.GetCellZoneIdListOfObjectRequest
    ) -> MeshingQueriesProtoModule.GetCellZoneIdListOfObjectResponse:
        """get_cell_zone_id_list_of_object RPC of MeshingQueriesService."""
        return self._stub.GetCellZoneIdListOfObject(request, metadata=self._metadata)

    @catch_grpc_error
    def get_face_zones_shared_by_regions_of_type(
        self,
        request: MeshingQueriesProtoModule.GetFaceZonesSharedByRegionsOfTypeRequest,
    ) -> MeshingQueriesProtoModule.GetFaceZonesSharedByRegionsOfTypeResponse:
        """get_face_zones_shared_by_regions_of_type RPC of MeshingQueriesService."""
        return self._stub.GetFaceZonesSharedByRegionsOfType(
            request, metadata=self._metadata
        )

    @catch_grpc_error
    def get_face_zones_of_regions(
        self, request: MeshingQueriesProtoModule.GetFaceZonesOfRegionsRequest
    ) -> MeshingQueriesProtoModule.GetFaceZonesOfRegionsResponse:
        """get_face_zones_of_regions RPC of MeshingQueriesService."""
        return self._stub.GetFaceZonesOfRegions(request, metadata=self._metadata)

    @catch_grpc_error
    def get_face_zones_of_labels(
        self, request: MeshingQueriesProtoModule.GetFaceZonesOfLabelsRequest
    ) -> MeshingQueriesProtoModule.GetFaceZonesOfLabelsResponse:
        """get_face_zones_of_labels RPC of MeshingQueriesService."""
        return self._stub.GetFaceZonesOfLabels(request, metadata=self._metadata)

    @catch_grpc_error
    def get_face_zone_id_list_of_labels(
        self,
        request: MeshingQueriesProtoModule.GetFaceZoneIdListOfLabelsRequest,
    ) -> MeshingQueriesProtoModule.GetFaceZoneIdListOfLabelsResponse:
        """get_face_zone_id_list_of_labels RPC of MeshingQueriesService."""
        return self._stub.GetFaceZoneIdListOfLabels(request, metadata=self._metadata)

    @catch_grpc_error
    def get_face_zones_of_objects(
        self, request: MeshingQueriesProtoModule.GetFaceZonesOfObjectsRequest
    ) -> MeshingQueriesProtoModule.GetFaceZonesOfObjectsResponse:
        """get_face_zones_of_objects RPC of MeshingQueriesService."""
        return self._stub.GetFaceZonesOfObjects(request, metadata=self._metadata)

    @catch_grpc_error
    def get_edge_zones_of_objects(
        self, request: MeshingQueriesProtoModule.GetEdgeZonesOfObjectsRequest
    ) -> MeshingQueriesProtoModule.GetEdgeZonesOfObjectsResponse:
        """get_edge_zones_of_objects RPC of MeshingQueriesService."""
        return self._stub.GetEdgeZonesOfObjects(request, metadata=self._metadata)

    @catch_grpc_error
    def get_face_zone_id_list_of_regions(
        self,
        request: MeshingQueriesProtoModule.GetFaceZoneIdListOfRegionsRequest,
    ) -> MeshingQueriesProtoModule.GetFaceZoneIdListOfRegionsResponse:
        """get_face_zone_id_list_of_regions RPC of MeshingQueriesService."""
        return self._stub.GetFaceZoneIdListOfRegions(request, metadata=self._metadata)

    @catch_grpc_error
    def get_prism_cell_zones(
        self,
        request: MeshingQueriesProtoModule.GetPrismCellZonesRequest,
    ) -> MeshingQueriesProtoModule.GetPrismCellZonesResponse:
        """get_prism_cell_zones RPC of MeshingQueriesService."""
        return self._stub.GetPrismCellZones(request, metadata=self._metadata)

    @catch_grpc_error
    def get_tet_cell_zones(
        self,
        request: MeshingQueriesProtoModule.GetTetCellZonesRequest,
    ) -> MeshingQueriesProtoModule.GetTetCellZonesResponse:
        """get_tet_cell_zones RPC of MeshingQueriesService."""
        return self._stub.GetTetCellZones(request, metadata=self._metadata)

    @catch_grpc_error
    def get_adjacent_cell_zones(
        self,
        request: MeshingQueriesProtoModule.GetAdjacentCellZonesRequest,
    ) -> MeshingQueriesProtoModule.GetAdjacentCellZonesResponse:
        """get_adjacent_cell_zones RPC of MeshingQueriesService."""
        return self._stub.GetAdjacentCellZones(request, metadata=self._metadata)

    @catch_grpc_error
    def get_adjacent_face_zones(
        self,
        request: MeshingQueriesProtoModule.GetAdjacentFaceZonesRequest,
    ) -> MeshingQueriesProtoModule.GetAdjacentFaceZonesResponse:
        """get_adjacent_face_zones RPC of MeshingQueriesService."""
        return self._stub.GetAdjacentFaceZones(request, metadata=self._metadata)

    @catch_grpc_error
    def get_adjacent_interior_and_boundary_face_zones(
        self,
        request: MeshingQueriesProtoModule.GetAdjacentInteriorAndBoundaryFaceZonesRequest,
    ) -> MeshingQueriesProtoModule.GetAdjacentInteriorAndBoundaryFaceZonesResponse:
        """get_adjacent_interior_and_boundary_face_zones RPC of
        MeshingQueriesService."""
        return self._stub.GetAdjacentInteriorAndBoundaryFaceZones(
            request, metadata=self._metadata
        )

    @catch_grpc_error
    def get_adjacent_zones_by_edge_connectivity(
        self,
        request: MeshingQueriesProtoModule.GetAdjacentZonesByEdgeConnectivityRequest,
    ) -> MeshingQueriesProtoModule.GetAdjacentZonesByEdgeConnectivityResponse:
        """get_adjacent_zones_by_edge_connectivity RPC of MeshingQueriesService."""
        return self._stub.GetAdjacentZonesByEdgeConnectivity(
            request, metadata=self._metadata
        )

    @catch_grpc_error
    def get_adjacent_zones_by_node_connectivity(
        self,
        request: MeshingQueriesProtoModule.GetAdjacentZonesByNodeConnectivityRequest,
    ) -> MeshingQueriesProtoModule.GetAdjacentZonesByNodeConnectivityResponse:
        """get_adjacent_zones_by_node_connectivity RPC of MeshingQueriesService."""
        return self._stub.GetAdjacentZonesByNodeConnectivity(
            request, metadata=self._metadata
        )

    @catch_grpc_error
    def get_shared_boundary_zones(
        self,
        request: MeshingQueriesProtoModule.GetSharedBoundaryZonesRequest,
    ) -> MeshingQueriesProtoModule.GetSharedBoundaryZonesResponse:
        """get_shared_boundary_zones RPC of MeshingQueriesService."""
        return self._stub.GetSharedBoundaryZones(request, metadata=self._metadata)

    @catch_grpc_error
    def get_interior_zones_connected_to_cell_zones(
        self,
        request: MeshingQueriesProtoModule.GetInteriorZonesConnectedToCellZonesRequest,
    ) -> MeshingQueriesProtoModule.GetInteriorZonesConnectedToCellZonesResponse:
        """get_interior_zones_connected_to_cell_zones RPC of MeshingQueriesService."""
        return self._stub.GetInteriorZonesConnectedToCellZones(
            request, metadata=self._metadata
        )

    @catch_grpc_error
    def get_face_zones_with_zone_specific_prisms_applied(
        self,
        request: MeshingQueriesProtoModule.Empty,
    ) -> MeshingQueriesProtoModule.GetFaceZonesWithZoneSpecificPrismsAppliedResponse:
        """get_face_zones_with_zone_specific_prisms_applied RPC of
        MeshingQueriesService."""
        return self._stub.GetFaceZonesWithZoneSpecificPrismsApplied(
            request, metadata=self._metadata
        )

    @catch_grpc_error
    def get_face_zones_of_prism_controls(
        self,
        request: MeshingQueriesProtoModule.GetFaceZonesOfPrismControlsRequest,
    ) -> MeshingQueriesProtoModule.GetFaceZonesOfPrismControlsResponse:
        """get_face_zones_of_prism_controls RPC of MeshingQueriesService."""
        return self._stub.GetFaceZonesOfPrismControls(request, metadata=self._metadata)

    @catch_grpc_error
    def get_baffles(
        self,
        request: MeshingQueriesProtoModule.GetBafflesRequest,
    ) -> MeshingQueriesProtoModule.GetBafflesResponse:
        """get_baffles RPC of MeshingQueriesService."""
        return self._stub.GetBaffles(request, metadata=self._metadata)

    @catch_grpc_error
    def get_embedded_baffles(
        self,
        request: MeshingQueriesProtoModule.Empty,
    ) -> MeshingQueriesProtoModule.GetEmbeddedBafflesResponse:
        """get_embedded_baffles RPC of MeshingQueriesService."""
        return self._stub.GetEmbeddedBaffles(request, metadata=self._metadata)

    @catch_grpc_error
    def get_wrapped_zones(
        self,
        request: MeshingQueriesProtoModule.Empty,
    ) -> MeshingQueriesProtoModule.GetWrappedZonesResponse:
        """get_wrapped_zones RPC of MeshingQueriesService."""
        return self._stub.GetWrappedZones(request, metadata=self._metadata)

    @catch_grpc_error
    def get_unreferenced_edge_zones(
        self,
        request: MeshingQueriesProtoModule.Empty,
    ) -> MeshingQueriesProtoModule.GetUnreferencedEdgeZonesResponse:
        """get_unreferenced_edge_zones RPC of MeshingQueriesService."""
        return self._stub.GetUnreferencedEdgeZones(request, metadata=self._metadata)

    @catch_grpc_error
    def get_unreferenced_face_zones(
        self,
        request: MeshingQueriesProtoModule.Empty,
    ) -> MeshingQueriesProtoModule.GetUnreferencedFaceZonesResponse:
        """get_unreferenced_face_zones RPC of MeshingQueriesService."""
        return self._stub.GetUnreferencedFaceZones(request, metadata=self._metadata)

    @catch_grpc_error
    def get_unreferenced_cell_zones(
        self,
        request: MeshingQueriesProtoModule.Empty,
    ) -> MeshingQueriesProtoModule.GetUnreferencedCellZonesResponse:
        """get_unreferenced_cell_zones RPC of MeshingQueriesService."""
        return self._stub.GetUnreferencedCellZones(request, metadata=self._metadata)

    @catch_grpc_error
    def get_unreferenced_edge_zones_of_filter(
        self,
        request: MeshingQueriesProtoModule.GetUnreferencedEdgeZonesOfFilterRequest,
    ) -> MeshingQueriesProtoModule.GetUnreferencedEdgeZonesOfFilterResponse:
        """get_unreferenced_edge_zones_of_filter RPC of MeshingQueriesService."""
        return self._stub.GetUnreferencedEdgeZonesOfFilter(
            request, metadata=self._metadata
        )

    @catch_grpc_error
    def get_unreferenced_face_zones_of_filter(
        self,
        request: MeshingQueriesProtoModule.GetUnreferencedFaceZonesOfFilterRequest,
    ) -> MeshingQueriesProtoModule.GetUnreferencedFaceZonesOfFilterResponse:
        """get_unreferenced_face_zones_of_filter RPC of MeshingQueriesService."""
        return self._stub.GetUnreferencedFaceZonesOfFilter(
            request, metadata=self._metadata
        )

    @catch_grpc_error
    def get_unreferenced_cell_zones_of_filter(
        self,
        request: MeshingQueriesProtoModule.GetUnreferencedCellZonesOfFilterRequest,
    ) -> MeshingQueriesProtoModule.GetUnreferencedCellZonesOfFilterResponse:
        """get_unreferenced_cell_zones_of_filter RPC of MeshingQueriesService."""
        return self._stub.GetUnreferencedCellZonesOfFilter(
            request, metadata=self._metadata
        )

    @catch_grpc_error
    def get_unreferenced_edge_zone_id_list_of_pattern(
        self,
        request: MeshingQueriesProtoModule.GetUnreferencedEdgeZoneIdListOfPatternRequest,
    ) -> MeshingQueriesProtoModule.GetUnreferencedEdgeZoneIdListOfPatternResponse:
        """get_unreferenced_edge_zone_id_list_of_pattern RPC of
        MeshingQueriesService."""
        return self._stub.GetUnreferencedEdgeZoneIdListOfPattern(
            request, metadata=self._metadata
        )

    @catch_grpc_error
    def get_unreferenced_face_zone_id_list_of_pattern(
        self,
        request: MeshingQueriesProtoModule.GetUnreferencedFaceZoneIdListOfPatternRequest,
    ) -> MeshingQueriesProtoModule.GetUnreferencedFaceZoneIdListOfPatternResponse:
        """get_unreferenced_face_zone_id_list_of_pattern RPC of
        MeshingQueriesService."""
        return self._stub.GetUnreferencedFaceZoneIdListOfPattern(
            request, metadata=self._metadata
        )

    @catch_grpc_error
    def get_unreferenced_cell_zone_id_list_of_pattern(
        self,
        request: MeshingQueriesProtoModule.GetUnreferencedCellZoneIdListOfPatternRequest,
    ) -> MeshingQueriesProtoModule.GetUnreferencedCellZoneIdListOfPatternResponse:
        """get_unreferenced_cell_zone_id_list_of_pattern RPC of
        MeshingQueriesService."""
        return self._stub.GetUnreferencedCellZoneIdListOfPattern(
            request, metadata=self._metadata
        )

    @catch_grpc_error
    def get_maxsize_cell_zone_by_volume(
        self,
        request: MeshingQueriesProtoModule.GetMaxsizeCellZoneByVolumeRequest,
    ) -> MeshingQueriesProtoModule.GetMaxsizeCellZoneByVolumeResponse:
        """get_maxsize_cell_zone_by_volume RPC of MeshingQueriesService."""
        return self._stub.GetMaxsizeCellZoneByVolume(request, metadata=self._metadata)

    @catch_grpc_error
    def get_maxsize_cell_zone_by_count(
        self,
        request: MeshingQueriesProtoModule.GetMaxsizeCellZoneByCountRequest,
    ) -> MeshingQueriesProtoModule.GetMaxsizeCellZoneByCountResponse:
        """get_maxsize_cell_zone_by_count RPC of MeshingQueriesService."""
        return self._stub.GetMaxsizeCellZoneByCount(request, metadata=self._metadata)

    @catch_grpc_error
    def get_minsize_face_zone_by_area(
        self,
        request: MeshingQueriesProtoModule.GetMinsizeFaceZoneByAreaRequest,
    ) -> MeshingQueriesProtoModule.GetMinsizeFaceZoneByAreaResponse:
        """get_minsize_face_zone_by_area RPC of MeshingQueriesService."""
        return self._stub.GetMinsizeFaceZoneByArea(request, metadata=self._metadata)

    @catch_grpc_error
    def get_minsize_face_zone_by_count(
        self,
        request: MeshingQueriesProtoModule.GetMinsizeFaceZoneByCountRequest,
    ) -> MeshingQueriesProtoModule.GetMinsizeFaceZoneByCountResponse:
        """get_minsize_face_zone_by_count RPC of MeshingQueriesService."""
        return self._stub.GetMinsizeFaceZoneByCount(request, metadata=self._metadata)

    @catch_grpc_error
    def get_face_zone_list_by_maximum_entity_count(
        self,
        request: MeshingQueriesProtoModule.GetFaceZoneListByMaximumEntityCountRequest,
    ) -> MeshingQueriesProtoModule.GetFaceZoneListByMaximumEntityCountResponse:
        """get_face_zone_list_by_maximum_entity_count RPC of MeshingQueriesService."""
        return self._stub.GetFaceZoneListByMaximumEntityCount(
            request, metadata=self._metadata
        )

    @catch_grpc_error
    def get_edge_zone_list_by_maximum_entity_count(
        self,
        request: MeshingQueriesProtoModule.GetEdgeZoneListByMaximumEntityCountRequest,
    ) -> MeshingQueriesProtoModule.GetEdgeZoneListByMaximumEntityCountResponse:
        """get_edge_zone_list_by_maximum_entity_count RPC of MeshingQueriesService."""
        return self._stub.GetEdgeZoneListByMaximumEntityCount(
            request, metadata=self._metadata
        )

    @catch_grpc_error
    def get_cell_zone_list_by_maximum_entity_count(
        self,
        request: MeshingQueriesProtoModule.GetCellZoneListByMaximumEntityCountRequest,
    ) -> MeshingQueriesProtoModule.GetCellZoneListByMaximumEntityCountResponse:
        """get_cell_zone_list_by_maximum_entity_count RPC of MeshingQueriesService."""
        return self._stub.GetCellZoneListByMaximumEntityCount(
            request, metadata=self._metadata
        )

    @catch_grpc_error
    def get_face_zone_list_by_maximum_zone_area(
        self,
        request: MeshingQueriesProtoModule.GetFaceZoneListByMaximumZoneAreaRequest,
    ) -> MeshingQueriesProtoModule.GetFaceZoneListByMaximumZoneAreaResponse:
        """get_face_zone_list_by_maximum_zone_area RPC of MeshingQueriesService."""
        return self._stub.GetFaceZoneListByMaximumZoneArea(
            request, metadata=self._metadata
        )

    @catch_grpc_error
    def get_face_zone_list_by_minimum_zone_area(
        self,
        request: MeshingQueriesProtoModule.GetFaceZoneListByMinimumZoneAreaRequest,
    ) -> MeshingQueriesProtoModule.GetFaceZoneListByMinimumZoneAreaResponse:
        """get_face_zone_list_by_minimum_zone_area RPC of MeshingQueriesService."""
        return self._stub.GetFaceZoneListByMinimumZoneArea(
            request, metadata=self._metadata
        )

    @catch_grpc_error
    def get_zones_with_free_faces(
        self,
        request: MeshingQueriesProtoModule.GetZonesWithFreeFacesRequest,
    ) -> MeshingQueriesProtoModule.GetZonesWithFreeFacesResponse:
        """get_zones_with_free_faces RPC of MeshingQueriesService."""
        return self._stub.GetZonesWithFreeFaces(request, metadata=self._metadata)

    @catch_grpc_error
    def get_zones_with_free_faces(
        self,
        request: MeshingQueriesProtoModule.GetZonesWithFreeFacesRequest,
    ) -> MeshingQueriesProtoModule.GetZonesWithFreeFacesResponse:
        """get_zones_with_free_faces RPC of MeshingQueriesService."""
        return self._stub.GetZonesWithFreeFaces(request, metadata=self._metadata)

    @catch_grpc_error
    def get_zones_with_multi_faces(
        self,
        request: MeshingQueriesProtoModule.GetZonesWithMultiFacesRequest,
    ) -> MeshingQueriesProtoModule.GetZonesWithMultiFacesResponse:
        """get_zones_with_multi_faces RPC of MeshingQueriesService."""
        return self._stub.GetZonesWithMultiFaces(request, metadata=self._metadata)

    @catch_grpc_error
    def get_overlapping_face_zones(
        self,
        request: MeshingQueriesProtoModule.GetOverlappingFaceZonesRequest,
    ) -> MeshingQueriesProtoModule.GetOverlappingFaceZonesResponse:
        """get_overlapping_face_zones RPC of MeshingQueriesService."""
        return self._stub.GetOverlappingFaceZones(request, metadata=self._metadata)

    @catch_grpc_error
    def get_zones_with_multi_faces(
        self,
        request: MeshingQueriesProtoModule.GetZonesWithMultiFacesRequest,
    ) -> MeshingQueriesProtoModule.GetZonesWithMultiFacesResponse:
        """get_zones_with_multi_faces RPC of MeshingQueriesService."""
        return self._stub.GetZonesWithMultiFaces(request, metadata=self._metadata)

    @catch_grpc_error
    def get_zones_with_marked_faces(
        self,
        request: MeshingQueriesProtoModule.GetZonesWithMarkedFacesRequest,
    ) -> MeshingQueriesProtoModule.GetZonesWithMarkedFacesResponse:
        """get_zones_with_marked_faces RPC of MeshingQueriesService."""
        return self._stub.GetZonesWithMarkedFaces(request, metadata=self._metadata)

    @catch_grpc_error
    def get_all_object_name_list(
        self,
        request: MeshingQueriesProtoModule.Empty,
    ) -> MeshingQueriesProtoModule.GetAllObjectNameListResponse:
        """get_all_object_name_list RPC of MeshingQueriesService."""
        return self._stub.GetAllObjectNameList(request, metadata=self._metadata)

    @catch_grpc_error
    def get_object_name_list_of_type(
        self,
        request: MeshingQueriesProtoModule.GetObjectNameListOfTypeRequest,
    ) -> MeshingQueriesProtoModule.GetObjectNameListOfTypeResponse:
        """get_object_name_list_of_type RPC of MeshingQueriesService."""
        return self._stub.GetObjectNameListOfType(request, metadata=self._metadata)

    @catch_grpc_error
    def get_objects_of_filter(
        self,
        request: MeshingQueriesProtoModule.GetObjectsOfFilterRequest,
    ) -> MeshingQueriesProtoModule.GetObjectsOfFilterResponse:
        """get_objects_of_filter RPC of MeshingQueriesService."""
        return self._stub.GetObjectsOfFilter(request, metadata=self._metadata)

    @catch_grpc_error
    def get_regions_of_object(
        self,
        request: MeshingQueriesProtoModule.GetRegionsOfObjectRequest,
    ) -> MeshingQueriesProtoModule.GetRegionsOfObjectResponse:
        """get_regions_of_object RPC of MeshingQueriesService."""
        return self._stub.GetRegionsOfObject(request, metadata=self._metadata)

    @catch_grpc_error
    def get_region_name_list_of_object(
        self,
        request: MeshingQueriesProtoModule.GetRegionNameListOfObjectRequest,
    ) -> MeshingQueriesProtoModule.GetRegionNameListOfObjectResponse:
        """get_region_name_list_of_object RPC of MeshingQueriesService."""
        return self._stub.GetRegionNameListOfObject(request, metadata=self._metadata)

    @catch_grpc_error
    def sort_regions_by_volume(
        self,
        request: MeshingQueriesProtoModule.SortRegionsByVolumeRequest,
    ) -> MeshingQueriesProtoModule.SortRegionsByVolumeResponse:
        """sort_regions_by_volume RPC of MeshingQueriesService."""
        return self._stub.SortRegionsByVolume(request, metadata=self._metadata)

    @catch_grpc_error
    def get_region_volume(
        self,
        request: MeshingQueriesProtoModule.GetRegionVolumeRequest,
    ) -> MeshingQueriesProtoModule.GetRegionVolumeResponse:
        """get_region_volume RPC of MeshingQueriesService."""
        return self._stub.GetRegionVolume(request, metadata=self._metadata)

    @catch_grpc_error
    def get_regions_of_filter(
        self,
        request: MeshingQueriesProtoModule.GetRegionsOfFilterRequest,
    ) -> MeshingQueriesProtoModule.GetRegionsOfFilterResponse:
        """get_regions_of_filter RPC of MeshingQueriesService."""
        return self._stub.GetRegionsOfFilter(request, metadata=self._metadata)

    @catch_grpc_error
    def get_region_name_list_of_pattern(
        self,
        request: MeshingQueriesProtoModule.GetRegionNameListOfPatternRequest,
    ) -> MeshingQueriesProtoModule.GetRegionNameListOfPatternResponse:
        """get_region_name_list_of_pattern RPC of MeshingQueriesService."""
        return self._stub.GetRegionNameListOfPattern(request, metadata=self._metadata)

    @catch_grpc_error
    def get_regions_of_face_zones(
        self,
        request: MeshingQueriesProtoModule.GetRegionsOfFaceZonesRequest,
    ) -> MeshingQueriesProtoModule.GetRegionsOfFaceZonesResponse:
        """get_regions_of_face_zones RPC of MeshingQueriesService."""
        return self._stub.GetRegionsOfFaceZones(request, metadata=self._metadata)

    @catch_grpc_error
    def find_join_pairs(
        self,
        request: MeshingQueriesProtoModule.FindJoinPairsRequest,
    ) -> MeshingQueriesProtoModule.FindJoinPairsResponse:
        """find_join_pairs RPC of MeshingQueriesService."""
        return self._stub.FindJoinPairs(request, metadata=self._metadata)

    @catch_grpc_error
    def get_region_name_list_of_face_zones(
        self,
        request: MeshingQueriesProtoModule.GetRegionNameListOfFaceZonesRequest,
    ) -> MeshingQueriesProtoModule.GetRegionNameListOfFaceZonesResponse:
        """get_region_name_list_of_face_zones RPC of MeshingQueriesService."""
        return self._stub.GetRegionNameListOfFaceZones(request, metadata=self._metadata)


class MeshingQueries:
    """Meshing Queries."""

    def __init__(self, service: MeshingQueriesService):
        """__init__ method of MeshingQueries class."""
        self.service = service
        self.region_types = ["fluid-fluid", "solid-solid", "fluid-solid"]
        self.orders = ["ascending", "descending"]

    docstring = None

    def __get_allowed_region_type(self, region_type):
        """Check region_type in available regions."""
        if region_type not in self.region_types:
            raise DisallowedValuesError("region-type", region_type, self.region_types)

    def _get_allowed_orders(self, order):
        """Check order in available orders."""
        if order not in self.orders:
            raise DisallowedValuesError("order", order, self.orders)

    def get_all_object_name_list(self) -> Any:
        """Return a list of all objects.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_all_object_name_list()
        """
        request = MeshingQueriesProtoModule.Empty()
        response = self.service.get_all_object_name_list(request)
        return response.objects

    def _get_allowed_object(self, object):
        """Check object in available objects."""
        allowed_args = [args for args in self.get_all_object_name_list()]
        if isinstance(object, list):
            for obj in object:
                if obj not in allowed_args:
                    raise DisallowedValuesError("object", obj, allowed_args)
        elif isinstance(object, str) and object not in allowed_args:
            raise DisallowedValuesError("object", object, allowed_args)

    def get_region_name_list_of_object(self, object) -> Any:
        """Return a list of regions in the specified object.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_region_name_list_of_object("elbow-fluid")
        """
        self._get_allowed_object(object)
        request = MeshingQueriesProtoModule.GetRegionNameListOfObjectRequest()
        request.object = object
        response = self.service.get_region_name_list_of_object(request)
        return response.regions

    def _get_allowed_region(self, region):
        """Check region in available regions."""
        objects = [objs for objs in self.get_all_object_name_list()]
        regions = []
        for obj in objects:
            regions.extend(self.get_region_name_list_of_object(obj))
        if isinstance(region, list):
            for reg in region:
                if reg not in regions:
                    raise DisallowedValuesError("region", reg, regions)
        elif isinstance(region, str) and region not in regions:
            raise DisallowedValuesError("region", region, regions)

    def get_face_zone_at_location(self, location) -> Any:
        """Return face zone at or closest to a specified location.

        Note:  This function is not applicable to polyhedral meshes.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_face_zone_at_location([1.4, 1.4, 1.4])
        """
        request = MeshingQueriesProtoModule.GetFaceZoneAtLocationRequest()
        request.location.x = location[0]
        request.location.y = location[1]
        request.location.z = location[2]
        response = self.service.get_face_zone_at_location(request)
        return response.face_zone_id

    def get_cell_zone_at_location(self, location) -> Any:
        """Return cell zone at or closest to a specified location.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_cell_zone_at_location([1.4, 1.4, 1.4])
        """
        request = MeshingQueriesProtoModule.GetCellZoneAtLocationRequest()
        request.location.x = location[0]
        request.location.y = location[1]
        request.location.z = location[2]
        response = self.service.get_cell_zone_at_location(request)
        return response.cell_zone_id

    def get_zones_of_type(self, type) -> Any:
        """Return a list of zones of the specified default zone type.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_zones_of_type("velocity-inlet")
        """
        request = MeshingQueriesProtoModule.GetZonesOfTypeRequest()
        request.type = type
        response = self.service.get_zones_of_type(request)
        return response.zone_ids

    def get_zones_of_group(self, group) -> Any:
        """Return a list of zones of the specified default zone group or user-defined
        group.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_zones_of_group("inlet")
        """
        request = MeshingQueriesProtoModule.GetZonesOfGroupRequest()
        request.group = group
        response = self.service.get_zones_of_group(request)
        return response.zone_ids

    def get_face_zones_of_filter(self, filter) -> Any:
        """Return a list of face zones whose names contain the specified filter string.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_face_zones_of_filter("*")
        """
        request = MeshingQueriesProtoModule.GetFaceZonesOfFilterRequest()
        request.filter = filter
        response = self.service.get_face_zones_of_filter(request)
        return response.face_zone_ids

    def get_cell_zones_of_filter(self, filter) -> Any:
        """Return a list of cell zones whose names contain the specified filter string.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_cell_zones_of_filter("*")
        """
        request = MeshingQueriesProtoModule.GetCellZonesOfFilterRequest()
        request.filter = filter
        response = self.service.get_cell_zones_of_filter(request)
        return response.cell_zone_ids

    def get_edge_zones_of_filter(self, filter) -> Any:
        """Return a list of edge zones whose names contain the specified filter string.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_edge_zones_of_filter("*")
        """
        request = MeshingQueriesProtoModule.GetEdgeZonesOfFilterRequest()
        request.filter = filter
        response = self.service.get_edge_zones_of_filter(request)
        return response.edge_zone_ids

    def get_node_zones_of_filter(self, filter) -> Any:
        """Return a list of node zones whose names contain the specified filter string.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_node_zones_of_filter("*")
        """
        request = MeshingQueriesProtoModule.GetNodeZonesOfFilterRequest()
        request.filter = filter
        response = self.service.get_node_zones_of_filter(request)
        return response.node_zone_ids

    def get_objects_of_type(self, type) -> Any:
        """Return a list of objects of the specified type.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_objects_of_type("mesh")
        """
        request = MeshingQueriesProtoModule.GetObjectsOfTypeRequest()
        request.type = type
        response = self.service.get_objects_of_type(request)
        return response.objects

    def get_face_zone_id_list_of_object(self, object) -> Any:
        """Return a list of face zones by ID in the specified face zone labels of an
        object.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_face_zone_id_list_of_object("elbow-fluid")
        """
        self._get_allowed_object(object)
        request = MeshingQueriesProtoModule.GetFaceZoneIdListOfObjectRequest()
        request.object = object
        response = self.service.get_face_zone_id_list_of_object(request)
        return response.face_zone_ids

    def get_edge_zone_id_list_of_object(self, object) -> Any:
        """Return a list of edge zones by ID in the specified face zone labels of an
        object.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_edge_zone_id_list_of_object("elbow-fluid")
        """
        self._get_allowed_object(object)
        request = MeshingQueriesProtoModule.GetEdgeZoneIdListOfObjectRequest()
        request.object = object
        response = self.service.get_edge_zone_id_list_of_object(request)
        return response.edge_zone_ids

    def get_cell_zone_id_list_of_object(self, object) -> Any:
        """Return a list of cell zones by ID in the specified face zone labels of an
        object.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_cell_zone_id_list_of_object("elbow-fluid")
        """
        self._get_allowed_object(object)
        request = MeshingQueriesProtoModule.GetCellZoneIdListOfObjectRequest()
        request.object = object
        response = self.service.get_cell_zone_id_list_of_object(request)
        return response.cell_zone_ids

    def get_face_zones_shared_by_regions_of_type(self, mesh_object, region_type) -> Any:
        """Return a list of face zones shared by regions of specified types in the mesh
        object specified, where region-type is fluid-fluid, solid-solid, or fluid-solid.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_face_zones_shared_by_regions_of_type("elbow-fluid", "fluid-fluid")
        """
        self._get_allowed_object(mesh_object)
        self.__get_allowed_region_type(region_type)
        request = MeshingQueriesProtoModule.GetFaceZonesSharedByRegionsOfTypeRequest()
        request.mesh_object = mesh_object
        request.region_type = region_type
        response = self.service.get_face_zones_shared_by_regions_of_type(request)
        return response.shared_face_zone_ids

    def get_face_zones_of_regions(self, object, region_name_list) -> Any:
        """Return a list of face zones in the specified regions.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_face_zones_of_regions("elbow-fluid", ["fluid"])
        """
        self._get_allowed_object(object)
        self._get_allowed_region(region_name_list)
        request = MeshingQueriesProtoModule.GetFaceZonesOfRegionsRequest()
        request.object = object
        for region in region_name_list:
            request.regions.append(region)
        response = self.service.get_face_zones_of_regions(request)
        return response.zone_ids

    def get_face_zones_of_labels(self, object, label_name_list) -> Any:
        """Return a list of face zones in the specified face zone labels of the object
        specified.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_face_zones_of_labels("elbow-fluid", ["inlet", "outlet", "wall", "internal"])
        """
        request = MeshingQueriesProtoModule.GetFaceZonesOfLabelsRequest()
        request.object = object
        for label in label_name_list:
            request.labels.append(label)
        response = self.service.get_face_zones_of_labels(request)
        return response.zone_ids

    def get_face_zone_id_list_of_labels(self, object, zone_label_list) -> Any:
        """Return a list of face zones by ID in the specified face zone labels of an
        object.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_face_zone_id_list_of_labels("elbow-fluid", ["outlet"])
        """
        request = MeshingQueriesProtoModule.GetFaceZoneIdListOfLabelsRequest()
        request.object = object
        for zone_label in zone_label_list:
            request.labels.append(zone_label)
        response = self.service.get_face_zone_id_list_of_labels(request)
        return response.zone_ids

    def get_face_zones_of_objects(self, object_list) -> Any:
        """Return a list of face zones in the specified objects.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_face_zones_of_objects(["elbow-fluid"])
        """
        self._get_allowed_object(object_list)
        request = MeshingQueriesProtoModule.GetFaceZonesOfObjectsRequest()
        for object in object_list:
            request.object_list.append(object)
        response = self.service.get_face_zones_of_objects(request)
        return response.face_zone_ids

    def get_edge_zones_of_objects(self, object_list) -> Any:
        """Return a list of edge zones in the specified objects.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_edge_zones_of_objects(["elbow-fluid"])
        """
        self._get_allowed_object(object_list)
        request = MeshingQueriesProtoModule.GetEdgeZonesOfObjectsRequest()
        for object in object_list:
            request.object_list.append(object)
        response = self.service.get_edge_zones_of_objects(request)
        return response.edge_zone_ids

    def get_face_zone_id_list_of_regions(self, object, region_list) -> Any:
        """Return a list of face zones by ID in the specified regions of an object.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_face_zone_id_list_of_regions("elbow-fluid", ["fluid"])
        """
        self._get_allowed_object(object)
        self._get_allowed_region(region_list)
        request = MeshingQueriesProtoModule.GetFaceZoneIdListOfRegionsRequest()
        request.object = object
        for region in region_list:
            request.labels.append(region)
        response = self.service.get_face_zone_id_list_of_regions(request)
        return response.zone_ids

    def get_prism_cell_zones(self, list_or_pattern) -> Any:
        """Return a list of prism cell zones.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_prism_cell_zones(["inlet", "outlet"])

            >>> meshing_session.meshing_queries.get_prism_cell_zones("*")
        """
        request = MeshingQueriesProtoModule.GetPrismCellZonesRequest()
        if isinstance(list_or_pattern, str):
            request.zone_name_or_pattern = list_or_pattern
        elif isinstance(list_or_pattern, list):
            for items in list_or_pattern:
                request.zones.append(items)
        response = self.service.get_prism_cell_zones(request)
        return response.prism_cell_zones

    def get_tet_cell_zones(self, list_or_pattern) -> Any:
        """Return a list of tet cell zones.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_tet_cell_zones(["inlet", "outlet"])

            >>> meshing_session.meshing_queries.get_tet_cell_zones("*")
        """
        request = MeshingQueriesProtoModule.GetTetCellZonesRequest()
        if isinstance(list_or_pattern, str):
            request.zone_name_or_pattern = list_or_pattern
        elif isinstance(list_or_pattern, list):
            for items in list_or_pattern:
                request.zones.append(items)
        response = self.service.get_tet_cell_zones(request)
        return response.tet_cell_zones

    def get_adjacent_cell_zones(self, list_or_name_or_pattern) -> Any:
        """Return adjacent cell zones for given face zone.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_adjacent_cell_zones([30])

            >>> meshing_session.meshing_queries.get_adjacent_cell_zones("*")
        """
        request = MeshingQueriesProtoModule.GetAdjacentCellZonesRequest()
        if isinstance(list_or_name_or_pattern, str):
            request.zone_name_or_pattern = list_or_name_or_pattern
        elif isinstance(list_or_name_or_pattern, list):
            for items in list_or_name_or_pattern:
                request.face_zone_ids.append(items)
        response = self.service.get_adjacent_cell_zones(request)
        return response.adjacent_cell_zones

    def get_adjacent_face_zones(self, list_or_name_or_pattern) -> Any:
        """Return adjacent boundary face zones for given cell zones.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_adjacent_face_zones([3460])

            >>> meshing_session.meshing_queries.get_adjacent_face_zones("*")
        """
        request = MeshingQueriesProtoModule.GetAdjacentFaceZonesRequest()
        if isinstance(list_or_name_or_pattern, str):
            request.zone_name_or_pattern = list_or_name_or_pattern
        elif isinstance(list_or_name_or_pattern, list):
            for items in list_or_name_or_pattern:
                request.cell_zone_ids.append(items)
        response = self.service.get_adjacent_face_zones(request)
        return response.adjacent_boundary_face_zones

    def get_adjacent_interior_and_boundary_face_zones(
        self, list_or_name_or_pattern
    ) -> Any:
        """Return adjacent interior and boundary face zones for given cell zones.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_adjacent_interior_and_boundary_face_zones([30])

            >>> meshing_session.meshing_queries.get_adjacent_interior_and_boundary_face_zones("fluid")

            >>> meshing_session.meshing_queries.get_adjacent_interior_and_boundary_face_zones("*")
        """
        request = (
            MeshingQueriesProtoModule.GetAdjacentInteriorAndBoundaryFaceZonesRequest()
        )
        if isinstance(list_or_name_or_pattern, str):
            request.zone_name_or_pattern = list_or_name_or_pattern
        elif isinstance(list_or_name_or_pattern, list):
            for items in list_or_name_or_pattern:
                request.cell_zone_ids.append(items)
        response = self.service.get_adjacent_interior_and_boundary_face_zones(request)
        return response.adjacent_interior_and_boundary_face_zones

    def get_adjacent_zones_by_edge_connectivity(self, list_or_name_or_pattern) -> Any:
        """Return adjacent zones based on edge connectivity.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_adjacent_zones_by_edge_connectivity([30])

            >>> meshing_session.meshing_queries.get_adjacent_zones_by_edge_connectivity("*")
        """
        request = MeshingQueriesProtoModule.GetAdjacentZonesByEdgeConnectivityRequest()
        if isinstance(list_or_name_or_pattern, str):
            request.zone_name_or_pattern = list_or_name_or_pattern
        elif isinstance(list_or_name_or_pattern, list):
            for items in list_or_name_or_pattern:
                request.zone_ids.append(items)
        response = self.service.get_adjacent_zones_by_edge_connectivity(request)
        return response.adjacent_zone_ids

    def get_adjacent_zones_by_node_connectivity(self, list_or_name_or_pattern) -> Any:
        """Return adjacent zones based on node connectivity.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_adjacent_zones_by_node_connectivity([30])

            >>> meshing_session.meshing_queries.get_adjacent_zones_by_node_connectivity("*")
        """
        request = MeshingQueriesProtoModule.GetAdjacentZonesByNodeConnectivityRequest()
        if isinstance(list_or_name_or_pattern, str):
            request.zone_name_or_pattern = list_or_name_or_pattern
        elif isinstance(list_or_name_or_pattern, list):
            for items in list_or_name_or_pattern:
                request.zone_ids.append(items)
        response = self.service.get_adjacent_zones_by_node_connectivity(request)
        return response.adjacent_zone_ids

    def get_shared_boundary_zones(self, list_or_name_or_pattern) -> Any:
        """Returns the number of faces and the boundary face zones that are shared with
        the specified cell zones.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_shared_boundary_zones("*")

            >>> meshing_session.meshing_queries.get_shared_boundary_zones([3460])
        """
        request = MeshingQueriesProtoModule.GetSharedBoundaryZonesRequest()
        if isinstance(list_or_name_or_pattern, str):
            request.cell_zone_name_or_pattern = list_or_name_or_pattern
        elif isinstance(list_or_name_or_pattern, list):
            for items in list_or_name_or_pattern:
                request.cell_zone_ids.append(items)
        response = self.service.get_shared_boundary_zones(request)
        return response.shared_boundary_zone_ids

    def get_interior_zones_connected_to_cell_zones(
        self, list_or_name_or_pattern
    ) -> Any:
        """Returns interior face zones connected to given cell zones.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_interior_zones_connected_to_cell_zones([3460])

            >>> meshing_session.meshing_queries.get_interior_zones_connected_to_cell_zones("*")
        """
        request = (
            MeshingQueriesProtoModule.GetInteriorZonesConnectedToCellZonesRequest()
        )
        if isinstance(list_or_name_or_pattern, str):
            request.cell_zone_name_or_pattern = list_or_name_or_pattern
        elif isinstance(list_or_name_or_pattern, list):
            for items in list_or_name_or_pattern:
                request.face_zone_ids.append(items)
        response = self.service.get_interior_zones_connected_to_cell_zones(request)
        return response.interior_zone_ids

    def get_face_zones_with_zone_specific_prisms_applied(self) -> Any:
        """Return a list of face zones with zone-specific prism settings applied.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_face_zones_with_zone_specific_prisms_applied()
        """
        request = MeshingQueriesProtoModule.Empty()
        response = self.service.get_face_zones_with_zone_specific_prisms_applied(
            request
        )
        return response.face_zone_ids

    def get_face_zones_of_prism_controls(self, control_name) -> Any:
        """Return a list of face zones to which the specified prism controls apply.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_face_zones_of_prism_controls("*")
        """
        request = MeshingQueriesProtoModule.GetFaceZonesOfPrismControlsRequest()
        request.control_name = control_name
        response = self.service.get_face_zones_of_prism_controls(request)
        return response.face_zone_ids

    def get_baffles(self, face_zone_list) -> Any:
        """Return the baffle zones based on the face zone list specified.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_baffles([29, 30])
        """
        request = MeshingQueriesProtoModule.GetBafflesRequest()
        for items in face_zone_list:
            request.face_zone_ids.append(items)
        response = self.service.get_baffles(request)
        return response.baffle_zone_ids

    def get_embedded_baffles(self) -> Any:
        """Return the embedded baffle zones.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_embedded_baffles()
        """
        request = MeshingQueriesProtoModule.Empty()
        response = self.service.get_embedded_baffles(request)
        return response.embedded_baffles_zone_ids

    def get_wrapped_zones(self) -> Any:
        """Return a list of wrapped face zones.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_wrapped_zones()
        """
        request = MeshingQueriesProtoModule.Empty()
        response = self.service.get_wrapped_zones(request)
        return response.wrapped_face_zone_ids

    def get_unreferenced_edge_zones(self) -> Any:
        """Return a list of unreferenced edge zones.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_unreferenced_edge_zones()
        """
        request = MeshingQueriesProtoModule.Empty()
        response = self.service.get_unreferenced_edge_zones(request)
        return response.unreferenced_edge_zone_ids

    def get_unreferenced_face_zones(self) -> Any:
        """Return a list of unreferenced face zones.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_unreferenced_face_zones()
        """
        request = MeshingQueriesProtoModule.Empty()
        response = self.service.get_unreferenced_face_zones(request)
        return response.unreferenced_face_zone_ids

    def get_unreferenced_cell_zones(self) -> Any:
        """Return a list of unreferenced cell zones.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_unreferenced_cell_zones()
        """
        request = MeshingQueriesProtoModule.Empty()
        response = self.service.get_unreferenced_cell_zones(request)
        return response.unreferenced_cell_zone_ids

    def get_unreferenced_edge_zones_of_filter(self, filter) -> Any:
        """Return a list of unreferenced edge zones whose names contain the specified
        filter string.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_unreferenced_edge_zones_of_filter("*")
        """
        request = MeshingQueriesProtoModule.GetUnreferencedEdgeZonesOfFilterRequest()
        request.filter = filter
        response = self.service.get_unreferenced_edge_zones_of_filter(request)
        return response.unreferenced_edge_zone_ids

    def get_unreferenced_face_zones_of_filter(self, filter) -> Any:
        """Return a list of unreferenced face zones whose names contain the specified
        filter string.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_unreferenced_face_zones_of_filter("*")
        """
        request = MeshingQueriesProtoModule.GetUnreferencedFaceZonesOfFilterRequest()
        request.filter = filter
        response = self.service.get_unreferenced_face_zones_of_filter(request)
        return response.unreferenced_face_zone_ids

    def get_unreferenced_cell_zones_of_filter(self, filter) -> Any:
        """Return a list of unreferenced cell zones whose names contain the specified
        filter string.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_unreferenced_cell_zones_of_filter("*")
        """
        request = MeshingQueriesProtoModule.GetUnreferencedCellZonesOfFilterRequest()
        request.filter = filter
        response = self.service.get_unreferenced_cell_zones_of_filter(request)
        return response.unreferenced_cell_zone_ids

    def get_unreferenced_edge_zone_id_list_of_pattern(self, pattern) -> Any:
        """Return a list of unreferenced edge zones by ID, whose names contain the
        specified pattern.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_unreferenced_edge_zone_id_list_of_pattern("*")
        """
        request = (
            MeshingQueriesProtoModule.GetUnreferencedEdgeZoneIdListOfPatternRequest()
        )
        request.pattern = pattern
        response = self.service.get_unreferenced_edge_zone_id_list_of_pattern(request)
        return response.unreferenced_edge_zone_ids

    def get_unreferenced_face_zone_id_list_of_pattern(self, pattern) -> Any:
        """Return a list of unreferenced face zones by ID, whose names contain the
        specified pattern.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_unreferenced_face_zone_id_list_of_pattern("*")
        """
        request = (
            MeshingQueriesProtoModule.GetUnreferencedFaceZoneIdListOfPatternRequest()
        )
        request.pattern = pattern
        response = self.service.get_unreferenced_face_zone_id_list_of_pattern(request)
        return response.unreferenced_face_zone_ids

    def get_unreferenced_cell_zone_id_list_of_pattern(self, pattern) -> Any:
        """Return a list of unreferenced cell zones by ID, whose names contain the
        specified pattern.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_unreferenced_cell_zone_id_list_of_pattern("*")
        """
        request = (
            MeshingQueriesProtoModule.GetUnreferencedCellZoneIdListOfPatternRequest()
        )
        request.pattern = pattern
        response = self.service.get_unreferenced_cell_zone_id_list_of_pattern(request)
        return response.unreferenced_cell_zone_ids

    def get_maxsize_cell_zone_by_volume(self, list_or_pattern) -> Any:
        """Return cell zone with maximum volume for given list or pattern of cell zones.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_maxsize_cell_zone_by_volume("*")

            >>> meshing_session.meshing_queries.get_maxsize_cell_zone_by_volume([3460])
        """
        request = MeshingQueriesProtoModule.GetMaxsizeCellZoneByVolumeRequest()
        if isinstance(list_or_pattern, str):
            request.cell_zone_pattern = list_or_pattern
        elif isinstance(list_or_pattern, list):
            if isinstance(list_or_pattern[0], int):
                for items in list_or_pattern:
                    request.cell_zone_ids.append(items)
            elif isinstance(list_or_pattern[0], str):
                for items in list_or_pattern:
                    request.cell_zone_names.append(items)
        response = self.service.get_maxsize_cell_zone_by_volume(request)
        return response.cell_zone_id

    def get_maxsize_cell_zone_by_count(self, list_or_pattern) -> Any:
        """Return cell zone with maximum count of elements for given list or pattern of
        cell zones.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_maxsize_cell_zone_by_count("*")

            >>> meshing_session.meshing_queries.get_maxsize_cell_zone_by_count([3460])
        """
        request = MeshingQueriesProtoModule.GetMaxsizeCellZoneByCountRequest()
        if isinstance(list_or_pattern, str):
            request.cell_zone_pattern = list_or_pattern
        elif isinstance(list_or_pattern, list):
            if isinstance(list_or_pattern[0], int):
                for items in list_or_pattern:
                    request.cell_zone_ids.append(items)
            elif isinstance(list_or_pattern[0], str):
                for items in list_or_pattern:
                    request.cell_zone_names.append(items)
        response = self.service.get_maxsize_cell_zone_by_count(request)
        return response.cell_zone_id

    def get_minsize_face_zone_by_area(self, list_or_pattern) -> Any:
        """Return face zone with minimum area for given list or pattern of face zones.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_minsize_face_zone_by_area("*")

            >>> meshing_session.meshing_queries.get_minsize_face_zone_by_area([29, 30, 31, 32, 33, 34])
        """
        request = MeshingQueriesProtoModule.GetMinsizeFaceZoneByAreaRequest()
        if isinstance(list_or_pattern, str):
            request.face_zone_pattern = list_or_pattern
        elif isinstance(list_or_pattern, list):
            if isinstance(list_or_pattern[0], int):
                for items in list_or_pattern:
                    request.face_zone_ids.append(items)
            elif isinstance(list_or_pattern[0], str):
                for items in list_or_pattern:
                    request.face_zone_names.append(items)
        response = self.service.get_minsize_face_zone_by_area(request)
        return response.face_zone_id

    def get_minsize_face_zone_by_count(self, list_or_pattern) -> Any:
        """Return face zone with minimum count of elements for given list or pattern of
        face zones.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_minsize_face_zone_by_count("*")

            >>> meshing_session.meshing_queries.get_minsize_face_zone_by_count([29, 30, 31, 32, 33, 34])
        """
        request = MeshingQueriesProtoModule.GetMinsizeFaceZoneByCountRequest()
        if isinstance(list_or_pattern, str):
            request.face_zone_pattern = list_or_pattern
        elif isinstance(list_or_pattern, list):
            if isinstance(list_or_pattern[0], int):
                for items in list_or_pattern:
                    request.face_zone_ids.append(items)
            elif isinstance(list_or_pattern[0], str):
                for items in list_or_pattern:
                    request.face_zone_names.append(items)
        response = self.service.get_minsize_face_zone_by_count(request)
        return response.face_zone_id

    def get_face_zone_list_by_maximum_entity_count(
        self, max_entity_count, only_boundary
    ) -> Any:
        """Return a list of face zones with a count below the maximum entity count
        (maximum-entity-count) specified. You can choose to restrict the report to only
        boundary edge zones, if required (only-boundary? set to True or False).

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_face_zone_list_by_maximum_entity_count(20, True)
        """
        request = MeshingQueriesProtoModule.GetFaceZoneListByMaximumEntityCountRequest()
        request.maximum_entity_count = max_entity_count
        request.only_boundary = only_boundary
        response = self.service.get_face_zone_list_by_maximum_entity_count(request)
        return response.face_zone_ids

    def get_edge_zone_list_by_maximum_entity_count(
        self, max_entity_count, only_boundary
    ) -> Any:
        """Return a list of edge zones with a count below the maximum entity count
        (maximum-entity-count) specified. You can choose to restrict the report to only
        boundary edge zones, if required (only-boundary? set to True or False).

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_edge_zone_list_by_maximum_entity_count(20, False)
        """
        request = MeshingQueriesProtoModule.GetEdgeZoneListByMaximumEntityCountRequest()
        request.maximum_entity_count = max_entity_count
        request.only_boundary = only_boundary
        response = self.service.get_edge_zone_list_by_maximum_entity_count(request)
        return response.edge_zone_ids

    def get_cell_zone_list_by_maximum_entity_count(self, maximum_entity_count) -> Any:
        """Return a list of cell zones with a count below the maximum entity count
        (maximum-entity-count) specified.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_cell_zone_list_by_maximum_entity_count(1)
        """
        request = MeshingQueriesProtoModule.GetCellZoneListByMaximumEntityCountRequest()
        request.maximum_entity_count = maximum_entity_count
        response = self.service.get_cell_zone_list_by_maximum_entity_count(request)
        return response.cell_zone_ids

    def get_face_zone_list_by_maximum_zone_area(self, maximum_zone_area) -> Any:
        """Return a list of face zones with a maximum zone area below the maximum-zone-
        area specified.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_face_zone_list_by_maximum_zone_area(100)
        """
        request = MeshingQueriesProtoModule.GetFaceZoneListByMaximumZoneAreaRequest()
        request.maximum_zone_area = maximum_zone_area
        response = self.service.get_face_zone_list_by_maximum_zone_area(request)
        return response.face_zone_ids

    def get_face_zone_list_by_minimum_zone_area(self, minimum_zone_area) -> Any:
        """Return a list of face zones with a minimum zone area above the minimum-zone-
        area specified.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_face_zone_list_by_minimum_zone_area(10)
        """
        request = MeshingQueriesProtoModule.GetFaceZoneListByMinimumZoneAreaRequest()
        request.minimum_zone_area = minimum_zone_area
        response = self.service.get_face_zone_list_by_minimum_zone_area(request)
        return response.face_zone_ids

    def get_zones_with_free_faces(self, list_or_pattern) -> Any:
        """Return a list of zones with free faces for the face zones specified.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_zones_with_free_faces("*")

            >>> meshing_session.meshing_queries.get_zones_with_free_faces([29, 30, 31, 32])

            >>> meshing_session.meshing_queries.get_zones_with_free_faces(["inlet", "outlet"])
        """
        request = MeshingQueriesProtoModule.GetZonesWithFreeFacesRequest()
        if isinstance(list_or_pattern, str):
            request.face_zone_pattern = list_or_pattern
        elif isinstance(list_or_pattern, list):
            if isinstance(list_or_pattern[0], int):
                for items in list_or_pattern:
                    request.face_zone_ids.append(items)
            elif isinstance(list_or_pattern[0], str):
                for items in list_or_pattern:
                    request.face_zone_names.append(items)
        response = self.service.get_zones_with_free_faces(request)
        return response.zones_with_free_faces

    def get_zones_with_multi_faces(self, list_or_pattern) -> Any:
        """Return a list of zones with multi-connected faces for the face zones
        specified.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_zones_with_multi_faces("*")

            >>> meshing_session.meshing_queries.get_zones_with_multi_faces([29, 30, 31, 32])

            >>> meshing_session.meshing_queries.get_zones_with_multi_faces(["inlet", "outlet"])
        """
        request = MeshingQueriesProtoModule.GetZonesWithMultiFacesRequest()
        if isinstance(list_or_pattern, str):
            request.face_zone_pattern = list_or_pattern
        elif isinstance(list_or_pattern, list):
            if isinstance(list_or_pattern[0], int):
                for items in list_or_pattern:
                    request.face_zone_ids.append(items)
            elif isinstance(list_or_pattern[0], str):
                for items in list_or_pattern:
                    request.face_zone_names.append(items)
        response = self.service.get_zones_with_multi_faces(request)
        return response.zones_with_multi_connected_faces

    def get_overlapping_face_zones(
        self, zone_name_pattern, area_tolerance, distance_tolerance
    ) -> Any:
        """Return a list of overlapping face zones based on the area-tolerance and
        distance-tolerance specified.

        .. code-block:: python

            >>> meshing_session.meshing_queries.GetOverlappingFaceZones("*", 0.1, 0.1)
        """
        request = MeshingQueriesProtoModule.GetOverlappingFaceZonesRequest()
        request.face_zone_name_or_pattern = zone_name_pattern
        request.area_tolerance = area_tolerance
        request.distance_tolerance = distance_tolerance
        response = self.service.get_overlapping_face_zones(request)
        return response.overlapping_face_zone_ids

    def get_zones_with_marked_faces(self, list_or_pattern) -> Any:
        """Return a list of zones with marked faces for the face zones specified.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_zones_with_marked_faces("*")

            >>> meshing_session.meshing_queries.get_zones_with_marked_faces([29, 30, 31, 32])

            >>> meshing_session.meshing_queries.get_zones_with_marked_faces(["inlet", "outlet"])
        """
        request = MeshingQueriesProtoModule.GetZonesWithMarkedFacesRequest()
        if isinstance(list_or_pattern, str):
            request.face_zone_pattern = list_or_pattern
        elif isinstance(list_or_pattern, list):
            if isinstance(list_or_pattern[0], int):
                for items in list_or_pattern:
                    request.face_zone_ids.append(items)
            elif isinstance(list_or_pattern[0], str):
                for items in list_or_pattern:
                    request.face_zone_names.append(items)
        response = self.service.get_zones_with_marked_faces(request)
        return response.zones_with_marked_faces

    def get_object_name_list_of_type(self, type) -> Any:
        """Return a list of objects of the specified type.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_object_name_list_of_type("mesh")
        """
        request = MeshingQueriesProtoModule.GetObjectNameListOfTypeRequest()
        request.type = type
        response = self.service.get_object_name_list_of_type(request)
        return response.objects

    def get_objects_of_filter(self, filter) -> Any:
        """Return a list of objects whose names contain the specified filter string.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_objects_of_filter("*")
        """
        request = MeshingQueriesProtoModule.GetObjectsOfFilterRequest()
        request.filter = filter
        response = self.service.get_objects_of_filter(request)
        return response.objects

    def get_regions_of_object(self, object) -> Any:
        """Return a list of regions in the specified object.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_regions_of_object("elbow-fluid")
        """
        self._get_allowed_object(object)
        request = MeshingQueriesProtoModule.GetRegionsOfObjectRequest()
        request.object = object
        response = self.service.get_regions_of_object(request)
        return response.regions

    def sort_regions_by_volume(self, object_name, order) -> Any:
        """Returns a sorted list of volumetric regions by volume for the object
        specified. Specify the order (ascending or descending).

        .. code-block:: python

            >>> meshing_session.meshing_queries.sort_regions_by_volume("elbow-fluid", "ascending")
        """
        self._get_allowed_object(object_name)
        self._get_allowed_orders(order)
        request = MeshingQueriesProtoModule.SortRegionsByVolumeRequest()
        request.object_name = object_name
        request.order = order
        response = self.service.sort_regions_by_volume(request)
        return response.regions

    def get_region_volume(self, object_name, region_name) -> Any:
        """Return the region volume for the specified region of an object.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_region_volume("elbow-fluid", "fluid")
        """
        self._get_allowed_object(object_name)
        self._get_allowed_region(region_name)
        request = MeshingQueriesProtoModule.GetRegionVolumeRequest()
        request.object_name = object_name
        request.region_name = region_name
        response = self.service.get_region_volume(request)
        return response.region_volume

    def get_regions_of_filter(self, object, filter) -> Any:
        """Return a list of regions in the specified object, whose names contain the
        specified filter string.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_regions_of_filter("elbow-fluid", "*")
        """
        request = MeshingQueriesProtoModule.GetRegionsOfFilterRequest()
        request.object = object
        request.filter = filter
        response = self.service.get_regions_of_filter(request)
        return response.regions

    def get_region_name_list_of_pattern(self, object, region_name_or_pattern) -> Any:
        """Return a list of regions in the specified object, whose names contain the
        specified name pattern.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_region_name_list_of_pattern("elbow-fluid", "*")
        """
        request = MeshingQueriesProtoModule.GetRegionNameListOfPatternRequest()
        request.object = object
        request.region_name_or_pattern = region_name_or_pattern
        response = self.service.get_region_name_list_of_pattern(request)
        return response.regions

    def get_regions_of_face_zones(self, list_of_face_zone_ids) -> Any:
        """Return a list of regions containing the face zones specified.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_regions_of_face_zones([29, 30, 31, 32, 33, 34])
        """
        request = MeshingQueriesProtoModule.GetRegionsOfFaceZonesRequest()
        for id in list_of_face_zone_ids:
            request.face_zone_ids.append(id)
        response = self.service.get_regions_of_face_zones(request)
        return response.regions

    def find_join_pairs(
        self, face_zone_list_or_pattern, join_tolerance, absolute_tolerance, join_angle
    ) -> Any:
        """Return the pairs of overlapping face zones based on the join tolerance and
        feature angle.

        .. code-block:: python

            >>> meshing_session.meshing_queries.find_join_pairs("outlet", 0.1, True, 40)

            >>> meshing_session.meshing_queries.find_join_pairs([32], 0.1, True, 40))

            >>> meshing_session.meshing_queries.find_join_pairs(["outlet"], 0.1, True, 40)
        """
        request = MeshingQueriesProtoModule.FindJoinPairsRequest()
        if isinstance(face_zone_list_or_pattern, str):
            request.face_zone_name_or_pattern = face_zone_list_or_pattern
        elif isinstance(face_zone_list_or_pattern, list):
            if isinstance(face_zone_list_or_pattern[0], int):
                for items in face_zone_list_or_pattern:
                    request.face_zone_ids.append(items)
            elif isinstance(face_zone_list_or_pattern[0], str):
                for items in face_zone_list_or_pattern:
                    request.face_zone_names.append(items)
        request.join_tolerance = join_tolerance
        request.absolute_tolerance = absolute_tolerance
        request.join_angle = join_angle
        response = self.service.find_join_pairs(request)
        return response.pairs

    def get_region_name_list_of_face_zones(self, list_or_pattern) -> Any:
        """Return a list of regions containing the face zones specified.

        .. code-block:: python

            >>> meshing_session.meshing_queries.get_region_name_list_of_face_zones([29, 30, 31, 32, 33, 34])
        """
        request = MeshingQueriesProtoModule.GetRegionNameListOfFaceZonesRequest()
        if isinstance(list_or_pattern, str):
            request.face_zone_name_or_pattern = list_or_pattern
        elif isinstance(list_or_pattern, list):
            for items in list_or_pattern:
                request.face_zone_ids.append(items)
        response = self.service.get_region_name_list_of_face_zones(request)
        return response.regions



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .les_zone_1 import les_zone as les_zone_cls
from .udf_zmotion_name import udf_zmotion_name as udf_zmotion_name_cls
from .axis_origin_1 import axis_origin as axis_origin_cls
from .axis_direction_1 import axis_direction as axis_direction_cls
from .omega import omega as omega_cls
from .relative_to_thread import relative_to_thread as relative_to_thread_cls
from .motion_spec import motion_spec as motion_spec_cls
from .cylindrical_fixed_var import cylindrical_fixed_var as cylindrical_fixed_var_cls
class disabled(Group):
    """
    Help not available.
    """

    fluent_name = "disabled"

    child_names = \
        ['les_zone', 'udf_zmotion_name', 'axis_origin', 'axis_direction',
         'omega', 'relative_to_thread', 'motion_spec',
         'cylindrical_fixed_var']

    les_zone: les_zone_cls = les_zone_cls
    """
    les_zone child of disabled.
    """
    udf_zmotion_name: udf_zmotion_name_cls = udf_zmotion_name_cls
    """
    udf_zmotion_name child of disabled.
    """
    axis_origin: axis_origin_cls = axis_origin_cls
    """
    axis_origin child of disabled.
    """
    axis_direction: axis_direction_cls = axis_direction_cls
    """
    axis_direction child of disabled.
    """
    omega: omega_cls = omega_cls
    """
    omega child of disabled.
    """
    relative_to_thread: relative_to_thread_cls = relative_to_thread_cls
    """
    relative_to_thread child of disabled.
    """
    motion_spec: motion_spec_cls = motion_spec_cls
    """
    motion_spec child of disabled.
    """
    cylindrical_fixed_var: cylindrical_fixed_var_cls = cylindrical_fixed_var_cls
    """
    cylindrical_fixed_var child of disabled.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class operating_density:
    fluent_name = ...
    child_names = ...
    enable = ...
    method = ...
    value = ...
    command_names = ...

    def print(self, ):
        """
        Print operating density value.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .linear_velocity import linear_velocity as linear_velocity_cls
from .rotational_velocity import rotational_velocity as rotational_velocity_cls
class constant_velocity(Group):
    """
    'constant_velocity' child.
    """

    fluent_name = "constant-velocity"

    child_names = \
        ['linear_velocity', 'rotational_velocity']

    linear_velocity: linear_velocity_cls = linear_velocity_cls
    """
    linear_velocity child of constant_velocity.
    """
    rotational_velocity: rotational_velocity_cls = rotational_velocity_cls
    """
    rotational_velocity child of constant_velocity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .field import field as field_cls
from .options_8 import options as options_cls
from .enabled_2 import enabled as enabled_cls
from .filter_minimum import filter_minimum as filter_minimum_cls
from .filter_maximum import filter_maximum as filter_maximum_cls
class filter_settings(Group):
    """
    'filter_settings' child.
    """

    fluent_name = "filter-settings"

    child_names = \
        ['field', 'options', 'enabled', 'filter_minimum', 'filter_maximum']

    field: field_cls = field_cls
    """
    field child of filter_settings.
    """
    options: options_cls = options_cls
    """
    options child of filter_settings.
    """
    enabled: enabled_cls = enabled_cls
    """
    enabled child of filter_settings.
    """
    filter_minimum: filter_minimum_cls = filter_minimum_cls
    """
    filter_minimum child of filter_settings.
    """
    filter_maximum: filter_maximum_cls = filter_maximum_cls
    """
    filter_maximum child of filter_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enabled_20 import enabled as enabled_cls
from .fixed_periodic_type import fixed_periodic_type as fixed_periodic_type_cls
from .period import period as period_cls
from .times_steps_per_period import times_steps_per_period as times_steps_per_period_cls
from .total_periods import total_periods as total_periods_cls
class fixed_periodic(Group):
    """
    Set period- or frequency-based fixed time-stepping parameters.
    """

    fluent_name = "fixed-periodic"

    child_names = \
        ['enabled', 'fixed_periodic_type', 'period', 'times_steps_per_period',
         'total_periods']

    enabled: enabled_cls = enabled_cls
    """
    enabled child of fixed_periodic.
    """
    fixed_periodic_type: fixed_periodic_type_cls = fixed_periodic_type_cls
    """
    fixed_periodic_type child of fixed_periodic.
    """
    period: period_cls = period_cls
    """
    period child of fixed_periodic.
    """
    times_steps_per_period: times_steps_per_period_cls = times_steps_per_period_cls
    """
    times_steps_per_period child of fixed_periodic.
    """
    total_periods: total_periods_cls = total_periods_cls
    """
    total_periods child of fixed_periodic.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .particle_thermolysis_rate import particle_thermolysis_rate as particle_thermolysis_rate_cls
from .film_thermolysis_rate import film_thermolysis_rate as film_thermolysis_rate_cls
class secondary_rate(Group):
    """
    'secondary_rate' child.
    """

    fluent_name = "secondary-rate"

    child_names = \
        ['particle_thermolysis_rate', 'film_thermolysis_rate']

    particle_thermolysis_rate: particle_thermolysis_rate_cls = particle_thermolysis_rate_cls
    """
    particle_thermolysis_rate child of secondary_rate.
    """
    film_thermolysis_rate: film_thermolysis_rate_cls = film_thermolysis_rate_cls
    """
    film_thermolysis_rate child of secondary_rate.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .consistency_index import consistency_index as consistency_index_cls
from .power_law_index import power_law_index as power_law_index_cls
from .yield_stress_threshold import yield_stress_threshold as yield_stress_threshold_cls
from .critical_shear_rate import critical_shear_rate as critical_shear_rate_cls
from .reference_temperature import reference_temperature as reference_temperature_cls
from .activation_energy import activation_energy as activation_energy_cls
class herschel_bulkley(Group):
    """
    'herschel_bulkley' child.
    """

    fluent_name = "herschel-bulkley"

    child_names = \
        ['option', 'consistency_index', 'power_law_index',
         'yield_stress_threshold', 'critical_shear_rate',
         'reference_temperature', 'activation_energy']

    option: option_cls = option_cls
    """
    option child of herschel_bulkley.
    """
    consistency_index: consistency_index_cls = consistency_index_cls
    """
    consistency_index child of herschel_bulkley.
    """
    power_law_index: power_law_index_cls = power_law_index_cls
    """
    power_law_index child of herschel_bulkley.
    """
    yield_stress_threshold: yield_stress_threshold_cls = yield_stress_threshold_cls
    """
    yield_stress_threshold child of herschel_bulkley.
    """
    critical_shear_rate: critical_shear_rate_cls = critical_shear_rate_cls
    """
    critical_shear_rate child of herschel_bulkley.
    """
    reference_temperature: reference_temperature_cls = reference_temperature_cls
    """
    reference_temperature child of herschel_bulkley.
    """
    activation_energy: activation_energy_cls = activation_energy_cls
    """
    activation_energy child of herschel_bulkley.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class parallel:
    fluent_name = ...
    child_names = ...
    thread_number_control = ...
    check_verbosity = ...
    partition = ...
    set = ...
    load_balance = ...
    multidomain = ...
    network = ...
    timer = ...
    command_names = ...

    def check(self, ):
        """
        Parallel check.
        """

    def show_connectivity(self, compute_node: int):
        """
        Show machine connectivity.
        
        Parameters
        ----------
            compute_node : int
                'compute_node' child.
        
        """

    def latency(self, ):
        """
        Show network latency.
        """

    def bandwidth(self, ):
        """
        Show network bandwidth.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .cone_type import cone_type as cone_type_cls
from .inject_as_film import inject_as_film as inject_as_film_cls
class injection_type(Group):
    """
    'injection_type' child.
    """

    fluent_name = "injection-type"

    child_names = \
        ['option', 'cone_type', 'inject_as_film']

    option: option_cls = option_cls
    """
    option child of injection_type.
    """
    cone_type: cone_type_cls = cone_type_cls
    """
    cone_type child of injection_type.
    """
    inject_as_film: inject_as_film_cls = inject_as_film_cls
    """
    inject_as_film child of injection_type.
    """
